@@ -116,7 +116,7 @@ ALLOC_T len;
 	while (len) {
 		new = nullline;
 		if (bg) {
-			for (; len; s++, len--) if (!isspace2(*s)) break;
+			for (; len; s++, len--) if (!Xisspace(*s)) break;
 			if (!len) break;
 			ERROR0(("%s: Cannot follow `%c'", s, bg));
 			Xfree(cp);
@@ -148,7 +148,7 @@ ALLOC_T len;
 			default:
 				if (*s == ARGV_FGJOB) bg = ARGV_FGJOB;
 				else if (*s == ARGV_BGJOB) bg = ARGV_BGJOB;
-				else if (!isspace2(*s)) {
+				else if (!Xisspace(*s)) {
 					cp = new = argv_addch(cp, &size, *s);
 					break;
 				}
@@ -206,7 +206,7 @@ char *CONST argv[];
 		list_free(args);
 	}
 
-	Xfclose(fp);
+	VOID_C Xfclose(fp);
 
 	return(0);
 }
