@@ -41,7 +41,7 @@ static CONST authcmd_t authcmdlist[] = {
 	DEFCMD("DIGEST-MD5", auth_digest, 0),
 #endif
 };
-#define	AUTHCMDLISTSIZ	arraysize(authcmdlist)
+#define	AUTHCMDLISTSIZ		arraysize(authcmdlist)
 
 
 static int NEAR auth_senderror(fp)
@@ -71,6 +71,7 @@ int code;
 char *s;
 {
 	char buf[POP_MAXBUF];
+	ALLOC_T len;
 	int n;
 
 	switch (mh_protocol) {
@@ -80,10 +81,10 @@ char *s;
 				break;
 			}
 			else if (code / 100 == 3)
-				n = snprintf2(buf, sizeof(buf), "+ %s\r\n", s);
-			else n = snprintf2(buf, sizeof(buf),
-				"%s %s\r\n", pop_errstr, s);
-			n = Xfwrite((u_char *)buf, n, fp);
+				len = Xsnprintf(buf, sizeof(buf), "+ %s\n", s);
+			else len = Xsnprintf(buf, sizeof(buf),
+				"%s %s\n", pop_errstr, s);
+			n = (Xfwrite(buf, len, fp) < (int)len) ? -1 : 0;
 			break;
 		case MHP_SMTP:
 			n = smtp_send(fp, code, s);
@@ -110,7 +111,7 @@ static char *NEAR auth_gencram(VOID_A)
 		ERRORx(("Cannot generate cram"));
 		return(NULL);
 	}
-	snprintf2(buf, sizeof(buf), "<%s@%s>", tmp, mydomain);
+	Xsnprintf(buf, sizeof(buf), "<%s@%s>", tmp, mydomain);
 
 	return(Xstrdup(buf));
 }
@@ -130,7 +131,7 @@ XFILE *fp;
 
 	size = sizeof(buf);
 	if (base64_decode((u_char *)buf, &size, arg, (ALLOC_T)-1) < 0) {
-		ERRORx(("%s: Illegal login format", arg));
+		ERRORx(("%s: Cannot decode Base64", arg));
 		return(auth_send(fp, 501, "AUTH illegal login format"));
 	}
 	buf[size] = '\0';
@@ -176,7 +177,7 @@ static int NEAR auth_plain(arg, fp)
 CONST char *arg;
 XFILE *fp;
 {
-	char *cp, buf[MAXLINEBUF + 1];
+	char *cp, *user, *pass, buf[MAXLINEBUF + 1];
 	ALLOC_T ptr, size;
 	int n;
 
@@ -187,23 +188,31 @@ XFILE *fp;
 
 	size = sizeof(buf);
 	if (base64_decode((u_char *)buf, &size, arg, (ALLOC_T)-1) < 0) {
-		ERRORx(("%s: Illegal login format", arg));
+		ERRORx(("%s: Cannot decode Base64", arg));
 		return(auth_send(fp, 501, "AUTH illegal login format"));
 	}
 	buf[size] = '\0';
 
+	user = pass = NULL;
 	for (ptr = (ALLOC_T)0; ptr < size; ptr++) if (!(buf[ptr])) break;
-	cp = &(buf[++ptr]);
-	if ((ptr *= 2) > size || strcmp(buf, cp) || !(cp = pwd_getpass(buf))) {
-		if (cp) ERROR0(("%s: Illegal username", buf));
-		return(auth_send(fp, 535, "AUTH authentication failed"));
+	if (ptr < size) {
+		user = &(buf[++ptr]);
+		for (; ptr < size; ptr++) if (!(buf[ptr])) break;
+		if (ptr < size) pass = &(buf[++ptr]);
+	}
+	if (!user || !pass) {
+		ERROR0(("%s: Illegal login format", arg));
+		return(auth_send(fp, 501, "AUTH illegal login format"));
 	}
 
-	if (!strcmp(cp, &(buf[ptr]))) n = pwd_login(buf);
-	else {
-		ERROR0(("%s: Password not match", arg));
-		n = -1;
-	}
+	cp = NULL;
+	n = -1;
+	if (*buf && strcmp(buf, user))
+		ERROR0(("%s: Username not match", user));
+	else if (!(cp = pwd_getpass(user))) /*EMPTY*/;
+	else if (strcmp(cp, pass))
+		ERROR0(("%s: Password not match", user));
+	else n = pwd_login(user);
 
 	if (n < 0) {
 		Xfree(cp);
@@ -318,7 +327,7 @@ CONST char *pass, *md5;
 
 	if (!pop_timestamp || !*pop_timestamp) return(-1);
 
-	snprintf2(tmp, sizeof(tmp), "%s%s", pop_timestamp, pass);
+	Xsnprintf(tmp, sizeof(tmp), "%s%s", pop_timestamp, pass);
 	size = sizeof(buf);
 	md5_encode(buf, &size, (u_char *)tmp, (ALLOC_T)-1);
 	msg_hex(tmp, sizeof(tmp), buf, size);
@@ -326,23 +335,45 @@ CONST char *pass, *md5;
 	return(strcmp(tmp, md5));
 }
 
-int auth_ehlo(s, fp)
-CONST char *s;
-XFILE *fp;
+int auth_getmaxid(VOID_A)
 {
-	char buf[SMTP_MAXBUF];
-	int i, n, flags;
+	return(AUTHCMDLISTSIZ);
+}
 
-	for (i = n = 0; i < AUTHCMDLISTSIZ; i++)
-		n += snprintf2(&(buf[n]), (int)sizeof(buf) - n,
-			" %s", authcmdlist[i].ident);
-	flags = smtp_flags;
-	smtp_flags |= SMTP_CONTINUED;
-	n = smtp_send(fp, 250, "%s%s", s, buf);
-	smtp_flags = flags;
-	if (n < 0) return(-1);
-	*buf = '=';
-	return(smtp_send(fp, 250, "%s%s", s, buf));
+int auth_getid(s, len)
+CONST char *s;
+ALLOC_T len;
+{
+	int i;
+
+	if (len == (ALLOC_T)-1) len = strlen(s);
+	for (i = 0; i < AUTHCMDLISTSIZ; i++) {
+		if (len != authcmdlist[i].len) continue;
+		if (!Xstrncasecmp(s, authcmdlist[i].ident, len)) return(i);
+	}
+
+	return(-1);
+}
+
+int auth_genlist(buf, size)
+char *buf;
+ALLOC_T size;
+{
+	char *cp;
+	int i, n;
+
+	cp = buf;
+	for (i = 0; i < AUTHCMDLISTSIZ; i++) {
+		if (incapableflags & (1 << i)) continue;
+		n = Xsnprintf(cp, size, "%s ", authcmdlist[i].ident);
+		if (n < 0) return(-1);
+		cp += n;
+		size -= n;
+	}
+	if (cp > buf) cp--;
+	*cp = '\0';
+
+	return(cp - buf);
 }
 
 int auth_setmech(argv, fp)
@@ -350,20 +381,13 @@ char *CONST *argv;
 XFILE *fp;
 {
 	CONST char *s;
-	ALLOC_T len;
 	int i, n;
 
 	if (!argv || !argv[0] || !*(argv[0])) {
 		ERROR0(("AUTH mechanism not specified"));
 		return(auth_send(fp, 501, "AUTH mechanism not specified"));
 	}
-	len = strlen(argv[0]);
-	for (i = n = 0; i < AUTHCMDLISTSIZ; i++) {
-		if (len != authcmdlist[i].len) continue;
-		if (!Xstrncasecmp(argv[0], authcmdlist[i].ident, len)) break;
-	}
-
-	if (i >= AUTHCMDLISTSIZ) {
+	if ((i = auth_getid(argv[0], (ALLOC_T)-1)) < 0) {
 		ERROR0(("%s: Illegal AUTH mechanism", argv[0]));
 		return(auth_send(fp, 504, "AUTH mechanism not available"));
 	}
