@@ -4,17 +4,10 @@
  *	BASE64 encoding/decoding in RFC3548
  */
 
-#include "machine.h"
-#include <string.h>
-#include <errno.h>
-#include <ctype.h>
-#include <sys/types.h>
+#include "headers.h"
+#include "kctype.h"
 
-#ifdef	NOERRNO
-extern int errno;
-#endif
-
-#define	BASE64_ENCSIZ	4
+#define	BASE64_ENCSIZ		4
 
 static CONST char encode64table[64] = {
 	'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H',
