@@ -44,6 +44,7 @@ typedef struct _config_t {
 #define	CF_OCTAL		000002
 #define	CF_STRING		000003
 #define	CF_PATH			000004
+#define	CF_REPORT		000005
 #define	CF_POP3			000010
 #define	CF_SMTP			000020
 #define	CF_NOUSER		000040
@@ -98,6 +99,7 @@ static config_t configlist[] = {
 	DEFCONF("rmm-timeout", '\0', rmmtimeout, DEFWAITTIMEOUT, CF_INT),
 	DEFCONF("send-timeout", '\0', sendtimeout, DEFWAITTIMEOUT, CF_INT),
 	DEFCONF("pick-timeout", '\0', picktimeout, DEFWAITTIMEOUT, CF_INT),
+	DEFCONF("reportmail", '\0', reportmail, 0, CF_REPORT),
 	ROTCONF("", 'D', daemonize, 0, CF_BOOL | CF_WRITEONCE),
 	ROTCONF("", 'i', interactive, 0, CF_BOOL | CF_WRITEONCE),
 	ROTCONF("", 's', serverrc, NULL, CF_PATH | CF_WRITEONCE),
@@ -113,6 +115,10 @@ static config_t configlist[] = {
 		CF_PATH | CF_NULLOK),
 	ROTCONF("users-deny", '\0', denyfile, DEFDENYFILE,
 		CF_PATH | CF_NULLOK),
+	ROTCONF("pop3-incapable", '\0', incapable, NULL,
+		CF_STRING | CF_POP3 | CF_NULLOK),
+	ROTCONF("smtp-incapable", '\0', incapable, NULL,
+		CF_STRING | CF_SMTP | CF_NULLOK),
 	ROTCONF("hostname", '\0', hostname, NULL, CF_STRING | CF_NULLOK),
 	ROTCONF("mh-profile", '\0', mhprofile, DEFMHPROFILE, CF_STRING),
 	ROTCONF("mhpopdrc", '\0', mhpopdrc, DEFMHPOPDRC, CF_STRING),
@@ -123,6 +129,13 @@ static config_t configlist[] = {
 	ROTCONF("debuglevel", 'd', debuglevel, 0, CF_INT | CF_PRIORARGS),
 };
 #define	CONFIGLISTSIZ		arraysize(configlist)
+static CONST char *CONST val_report[] = {
+	"never",
+	"nomail",
+	"mail",
+	"any",
+	NULL,
+};
 
 static int NEAR conf_isvalid __P_((int));
 static int NEAR conf_canset __P_((int, int));
@@ -130,6 +143,7 @@ static VOID NEAR conf_usage __P_((VOID_A));
 static VOID NEAR conf_version __P_((VOID_A));
 static int NEAR conf_a2i __P_((int));
 static int NEAR conf_strtoi __P_((CONST char *, int));
+static int NEAR conf_enumtoi __P_((CONST char *, CONST char *CONST *));
 static VOID NEAR conf_setval __P_((int, CONST char *, int));
 
 
@@ -178,6 +192,7 @@ int flags;
 			case CF_INT:
 			case CF_BOOL:
 			case CF_OCTAL:
+			case CF_REPORT:
 				*((int *)vp) = def_num(i);
 				break;
 			default:
@@ -195,12 +210,12 @@ static VOID NEAR conf_usage(VOID_A)
 {
 	int i;
 
-	fprintf(stderr, "Usage: %s [-hv] [-", myname);
+	Xfprintf(Xstderr, "Usage: %s [-hv] [-", myname);
 	for (i = 0; i < CONFIGLISTSIZ; i++) {
 		if (!(configlist[i].option) || !conf_isvalid(i)) continue;
-		fputc(configlist[i].option, stderr);
+		Xfputc(configlist[i].option, Xstderr);
 	}
-	fprintf(stderr, "]\n");
+	Xfprintf(Xstderr, "]\n");
 }
 
 char *conf_getversion(lenp)
@@ -209,9 +224,9 @@ int *lenp;
 	char *cp;
 	ALLOC_T len;
 
-	for (cp = version; *cp; cp++) if (isblank2(*cp)) break;
-	while (isblank2(*(++cp)));
-	for (len = (ALLOC_T)1; cp[len]; len++) if (isblank2(cp[len])) break;
+	for (cp = version; *cp; cp++) if (Xisblank(*cp)) break;
+	while (Xisblank(*(++cp)));
+	for (len = (ALLOC_T)1; cp[len]; len++) if (Xisblank(cp[len])) break;
 	if (lenp) *lenp = (int)len;
 
 	return(cp);
@@ -223,14 +238,14 @@ static VOID NEAR conf_version(VOID_A)
 	int len;
 
 	cp = conf_getversion(&len);
-	fprintf(stderr, "%s Ver. %-.*s\n", myname, len, cp);
+	Xfprintf(Xstderr, "%s Ver. %-.*s\n", myname, len, cp);
 }
 
 static int NEAR conf_a2i(c)
 int c;
 {
 	if (c < 0) return(-1);
-	else if (isdigit2(c)) return(c - '0');
+	else if (Xisdigit(c)) return(c - '0');
 	else return(-1);
 }
 
@@ -250,6 +265,18 @@ int base;
 	return(n);
 }
 
+static int NEAR conf_enumtoi(s, val)
+CONST char *s;
+CONST char *CONST *val;
+{
+	int n;
+
+	if (!s || !*s || !val) return(-1);
+	for (n = 0; val[n]; n++) if (!Xstrcasecmp(s, val[n])) return(n);
+
+	return(-1);
+}
+
 static VOID NEAR conf_setval(n, s, flags)
 int n;
 CONST char *s;
@@ -263,7 +290,7 @@ int flags;
 	if (n < 0 || n >= CONFIGLISTSIZ) return;
 	if (!(vp = configlist[n].var) || !conf_canset(n, flags)) return;
 
-	if (s) while (isspace2(*s)) s++;
+	if (s) while (Xisspace(*s)) s++;
 	else s = nullstr;
 
 	if (*(configlist[n].ident)) cp = configlist[n].ident;
@@ -277,7 +304,7 @@ int flags;
 	switch (configtype(n)) {
 		case CF_BOOL:
 			if ((flags & CF_SETBYFILE)
-			&& (!*s || strchr("Nn0", *s)))
+			&& (!*s || Xstrchr("Nn0", *s)))
 				*((int *)vp) = 0;
 			else *((int *)vp) = 1;
 			break;
@@ -288,6 +315,14 @@ int flags;
 		case CF_OCTAL:
 			if ((val = conf_strtoi(s, 8)) >= 0) *((int *)vp) = val;
 			break;
+		case CF_REPORT:
+			if ((val = conf_enumtoi(s, val_report)) < 0) {
+				ERROR0(("%s: Illegal configuration for %s",
+					s, configlist[n].ident));
+				return;
+			}
+			*((int *)vp) = val;
+			break;
 		case CF_PATH:
 			if (*s && *s != '/') {
 				ERROR0(("%s: Relative path (%s) not allowed",
@@ -318,7 +353,7 @@ char *CONST argv[];
 
 	for (n = 1; n < argc; n++) {
 		if (argv[n][0] != '-' || !argv[n][1]) {
-			fprintf(stderr, "%s: Illegal argument\n", argv[n]);
+			Xfprintf(Xstderr, "%s: Illegal argument\n", argv[n]);
 			conf_usage();
 			return(-1);
 		}
@@ -337,7 +372,7 @@ char *CONST argv[];
 			if (argv[n][1] == configlist[i].option) break;
 		}
 		if (i >= CONFIGLISTSIZ) {
-			fprintf(stderr, "%s: Illegal option\n", argv[n]);
+			Xfprintf(Xstderr, "%s: Illegal option\n", argv[n]);
 			conf_usage();
 			return(-1);
 		}
@@ -345,7 +380,8 @@ char *CONST argv[];
 		cp = &(argv[n][2]);
 		if (*cp || configtype(i) == CF_BOOL) /*EMPTY*/;
 		else if (++n >= argc || !*(cp = argv[n])) {
-			fprintf(stderr, "%s: Too few argument\n", argv[n - 1]);
+			Xfprintf(Xstderr,
+				"%s: Too few argument\n", argv[n - 1]);
 			conf_usage();
 			return(-1);
 		}
@@ -370,7 +406,7 @@ int flags;
 			ERROR0(("%s: Unexpected blank line", fp -> path));
 			return(NULL);
 		}
-		if ((flags & XF_NOCOMMENT) || !strchr("#;", *buf)) break;
+		if ((flags & XF_NOCOMMENT) || !Xstrchr("#;", *buf)) break;
 
 		Xfree(buf);
 	}
@@ -378,10 +414,10 @@ int flags;
 	if (!buf || (flags & XF_KEEPSPACE)) return(buf);
 
 	for (cp = buf; cp < &(buf[len]); cp++) {
-		if (!isspace2(*cp)) continue;
+		if (!Xisspace(*cp)) continue;
 		*cp = ' ';
 		for (i = 1; &(cp[i]) < &(buf[len]); i++)
-			if (!isspace2(cp[i])) break;
+			if (!Xisspace(cp[i])) break;
 		if (i <= 1) continue;
 		memmove(&(cp[1]), &(cp[i]), &(buf[len]) - &(cp[i]) + 1);
 		len -= i - 1;
@@ -428,7 +464,7 @@ int flags;
 	}
 
 	n = (Xferror(fp)) ? -1 : 0;
-	Xfclose(fp);
+	VOID_C Xfclose(fp);
 
 	return(n);
 }
@@ -447,6 +483,7 @@ VOID conf_push(VOID_A)
 			case CF_INT:
 			case CF_BOOL:
 			case CF_OCTAL:
+			case CF_REPORT:
 				stack_num(i) = *((int *)vp);
 				break;
 			default:
@@ -472,11 +509,13 @@ VOID conf_pop(VOID_A)
 			case CF_INT:
 			case CF_BOOL:
 			case CF_OCTAL:
+			case CF_REPORT:
 				*((int *)vp) = stack_num(i);
 				break;
 			default:
 				Xfree(*((char **)vp));
 				*((char **)vp) = stack_str(i);
+				stack_str(i) = NULL;
 				break;
 		}
 	}
