@@ -29,9 +29,9 @@ int *np;
 	char buf[MAXLONGWIDTH + 1];
 	int n;
 
-	if (!s || !isdigit2(*s)) return(0);
+	if (!s || !Xisdigit(*s)) return(0);
 	n = atoi(s);
-	snprintf2(buf, sizeof(buf), "%d", n);
+	Xsnprintf(buf, sizeof(buf), "%d", n);
 	if (strcmp(s, buf)) return(0);
 	if (np) *np = n;
 
@@ -73,19 +73,19 @@ int **listp;
 		if (dir_isdot(dp -> d_name)) continue;
 		if (!dir_isnumeric(dp -> d_name, &val)) continue;
 
-		snprintf2(&(path[n]), (int)sizeof(path) - n, "/%d", val);
+		Xsnprintf(&(path[n]), (int)sizeof(path) - n, "/%d", val);
 		if (stat_isreg(path, 0) <= 0) continue;
 
 		new = (int *)Xrealloc(list, (argc + 1) * sizeof(int));
 		if (!new) {
 			Xfree(list);
-			closedir(dirp);
+			VOID_C closedir(dirp);
 			return(-1);
 		}
 		list = new;
 		list[argc++] = val;
 	}
-	closedir(dirp);
+	VOID_C closedir(dirp);
 
 	if (!listp) Xfree(list);
 	else {
@@ -117,7 +117,7 @@ int **listp;
 		for (j = 0; args[j]; j++) {
 			if (!dir_isnumeric(args[j], &val)) continue;
 
-			snprintf2(&(path[n]), (int)sizeof(path) - n,
+			Xsnprintf(&(path[n]), (int)sizeof(path) - n,
 				"/%d", val);
 			if (stat_isreg(path, 0) <= 0) continue;
 
