@@ -100,11 +100,11 @@ typedef struct fstab		mnt_t;
 #endif	/* USEFSDATA */
 
 #ifndef	MOUNTED
-#define	MOUNTED		"/etc/mtab"
+#define	MOUNTED			"/etc/mtab"
 #endif
 
-#define	FSYS_MNTNFS	"nfs"
-#define	FSYS_MNTNFSLEN	strsize(FSYS_MNTNFS)
+#define	FSYS_MNTNFS		"nfs"
+#define	FSYS_MNTNFSLEN		strsize(FSYS_MNTNFS)
 
 static int NEAR fsys_getmnt __P_((CONST char *, mnt_t *));
 
@@ -153,7 +153,7 @@ mnt_t *mntp;
 		len += strlen(host) + 1;
 		if (!(new = Xrealloc(fsname, len))) return(NULL);
 		fsname = new;
-		snprintf2(fsname. len, "%s:%s", host, cp);
+		Xsnprintf(fsname. len, "%s:%s", host, cp);
 	}
 
 	cp = &(buf[mnt_ptr + vmntp -> vmt_data[VMT_STUB].vmt_off]);
@@ -373,7 +373,7 @@ mnt_t *mntbuf;
 		&& path[len] && path[len] != '/'))
 			continue;
 		match = len;
-		strcpy(fsname, mntp -> mnt_fsname);
+		Xstrcpy(fsname, mntp -> mnt_fsname);
 	}
 	Xendmntent(fp);
 
@@ -397,10 +397,10 @@ CONST char *path;
 	char *cp, cwd[MAXPATHLEN], rpath[MAXPATHLEN];
 	int n;
 
-	n = snprintf2(rpath, sizeof(rpath), "%s", path);
+	n = Xsnprintf(rpath, sizeof(rpath), "%s", path);
 	while (n > 1 && rpath[n - 1] == '/') rpath[--n] = '\0';
 	if ((n = stat_isdir(rpath, XF_IGNOREERR)) < 0) return(NULL);
-	if (!n && (cp = strrchr(rpath, '/')) && cp > rpath) *cp = '\0';
+	if (!n && (cp = Xstrrchr(rpath, '/')) && cp > rpath) *cp = '\0';
 
 	if (!Xgetwd(cwd) || Xchdir(rpath) < 0) return(NULL);
 	cp = Xgetwd(rpath);
