@@ -4,6 +4,9 @@
  *	function prototype declarations
  */
 
+#include "depend.h"
+#include "string.h"
+
 /* macros */
 #ifdef	USESTRERROR
 #define	Xstrerror		strerror
@@ -63,14 +66,20 @@
 #define	strnpathcmp		strncmp
 #endif
 
+#ifdef	ULONGIOCTL
+typedef unsigned long		ioctlreq_t;
+#else
+typedef int			ioctlreq_t;
+#endif
+
 #define	base64siz(n)		((((n) - 1) / 3 + 1) * 4)
 
 /* syscall.c */
 extern int Xselect __P_((int, int, int));
-extern int Xread __P_((int, u_char *, ALLOC_T, int, CONST char *));
-extern int Xwrite __P_((int, CONST u_char *, ALLOC_T, int, CONST char *));
+extern int Xread __P_((int, char *, ALLOC_T, int, CONST char *));
+extern int Xwrite __P_((int, CONST char *, ALLOC_T, int, CONST char *));
 extern int Xopen __P_((CONST char *, int, int, int));
-extern VOID Xclose __P_((int, CONST char *));
+extern int Xclose __P_((int, CONST char *));
 extern off_t Xlseek __P_((int, off_t, int, CONST char *));
 extern int Xfcntl __P_((int, int, VOID_P, CONST char *));
 #ifndef	NOFLOCK
@@ -96,26 +105,7 @@ extern char *Xmalloc __P_((ALLOC_T));
 extern char *Xrealloc __P_((VOID_P, ALLOC_T));
 extern char *Xstrdup __P_((CONST char *));
 extern char *Xstrndup __P_((CONST char *, ALLOC_T));
-extern VOID Xfclose __P_((XFILE *));
-extern XFILE *Xfopen __P_((CONST char *, CONST char *, int, int));
-extern XFILE *Xfdopen __P_((int, CONST char *, int, int, CONST char *));
-extern VOID Xclearerr __P_((XFILE *));
-extern int Xfeof __P_((XFILE *));
-extern int Xferror __P_((XFILE *));
-extern int Xfflush __P_((XFILE *));
-extern int Xfseek __P_((XFILE *, off_t, int));
-extern off_t Xftell __P_((XFILE *));
-extern int Xrewind __P_((XFILE *));
-extern int Xfread __P_((u_char *, ALLOC_T, XFILE *));
-extern int Xfwrite __P_((CONST u_char *, ALLOC_T, XFILE *));
-extern int Xfgetc __P_((XFILE *));
-extern int Xfputc __P_((int, XFILE *));
-extern char *Xfgets __P_((XFILE *, ALLOC_T *, int));
-extern int Xfputs __P_((CONST char *, XFILE *));
-extern int Xungetc __P_((int, XFILE *));
 extern int Xusleep __P_((u_long));
-extern int Xstrcasecmp __P_((CONST char *, CONST char *));
-extern int Xstrncasecmp __P_((CONST char *, CONST char *, ALLOC_T));
 extern int Xdaemon __P_((int, int));
 
 /* list.c */
@@ -130,7 +120,7 @@ time_t Xtime __P_((time_t *));
 int time_getdatestr __P_((char *, ALLOC_T));
 
 /* term.c */
-extern int Xioctl __P_((int, int, VOID_P));
+extern int Xioctl __P_((int, ioctlreq_t, VOID_P));
 extern VOID term_safeclose __P_((int, CONST char *));
 extern VOID term_loadtermio __P_((int, CONST char *, CONST char *));
 extern VOID term_savetermio __P_((int, char **, char **));
@@ -164,7 +154,7 @@ extern int wait_all __P_((int));
 extern VOID md5_encode __P_((u_char *, ALLOC_T *, CONST u_char *, ALLOC_T));
 extern VOID md5_hmac __P_((u_char *, ALLOC_T *, CONST char *, CONST char *));
 extern int md5_fencode __P_((u_char *, ALLOC_T *, VOID_P,
-	int (*)__P_((u_char *, ALLOC_T, VOID_P))));
+	int (*)__P_((char *, ALLOC_T, VOID_P))));
 
 /* base64.c */
 extern int base64_encode __P_((char *, ALLOC_T, CONST u_char *, ALLOC_T));
@@ -185,8 +175,7 @@ extern VOID log_end __P_((VOID_A));
 extern VOID log_header __P_((CONST char *, CONST char *, int, int));
 extern VOID log_body __P_((CONST char *, ...));
 extern char *log_strerror __P_((VOID_A));
-extern VOID log_dump __P_((u_char *, ALLOC_T, CONST char *));
-extern VOID log_fpdump __P_((int, CONST char *, XFILE *));
+extern VOID log_debugfp __P_((int, CONST char *, XFILE *));
 
 /* config.c */
 extern VOID conf_init __P_((int));
@@ -259,6 +248,8 @@ extern VOID msg_hex __P_((char *, ALLOC_T, CONST u_char *, ALLOC_T));
 
 /* auth.c */
 extern int auth_cmppasswd __P_((CONST char *, CONST char *));
-extern int auth_ehlo __P_((CONST char *, XFILE *));
+extern int auth_getmaxid __P_((VOID_A));
+extern int auth_getid __P_((CONST char *, ALLOC_T));
+extern int auth_genlist __P_((char *, ALLOC_T));
 extern int auth_setmech __P_((char *CONST *, XFILE *));
 extern int auth_input __P_((CONST char *, XFILE *));
