@@ -9,7 +9,7 @@
 
 
 int list_count(list)
-char **list;
+char *CONST *list;
 {
 	int i;
 
@@ -32,21 +32,25 @@ char **list_init(VOID_A)
 char **list_add(list, n, s, len)
 char **list;
 int n;
-char *s;
+CONST char *s;
 ALLOC_T len;
 {
-	char **new;
+	char *cp, **new;
 
 	if (n < 0) n = list_count(list);
 	if (len == (ALLOC_T)-1) len = strlen(s);
 
-	if (!(new = (char **)Xrealloc(list, (n + 1 + 1) * sizeof(char *)))
-	|| !(s = Xstrndup(s, len))) {
-		while (n-- > 0) Xfree(list[n]);
+	new = (char **)Xrealloc(list, (n + 1 + 1) * sizeof(char *));
+	if (!new) cp = NULL;
+	else if (s == nullstr) cp = nullline;
+	else cp = Xstrndup(s, len);
+	if (!cp) {
+		while (n-- > 0) if (list[n] != nullline) Xfree(list[n]);
 		Xfree(list);
 		return(NULL);
 	}
-	new[n] = s;
+
+	new[n] = cp;
 	new[++n] = NULL;
 
 	return(new);
@@ -76,6 +80,6 @@ char **list;
 
 	if (!list) return;
 
-	for (i = 0; list[i]; i++) Xfree(list[i]);
+	for (i = 0; list[i]; i++) if (list[i] != nullline) Xfree(list[i]);
 	Xfree(list);
 }
