@@ -6,7 +6,6 @@
 
 #include "mhpopd.h"
 #include "kctype.h"
-#include <sys/param.h>
 
 #ifndef	NOSYSLOG
 #include <syslog.h>
@@ -19,6 +18,7 @@ static int log_line = -1;
 static int log_errno = -1;
 
 static XFILE *NEAR log_open __P_((VOID_A));
+static VOID log_dump __P_((CONST u_char *, ALLOC_T, CONST char *));
 
 
 VOID log_init(VOID_A)
@@ -47,10 +47,10 @@ static XFILE *NEAR log_open(VOID_A)
 
 	if (!logdir || *logdir != '/') return(NULL);
 	if (Xmkdir(logdir, 0755) < 0) return(NULL);
-	snprintf2(path, sizeof(path), "%s/%s", logdir, myname);
+	Xsnprintf(path, sizeof(path), "%s/%s", logdir, myname);
 	if (maxlogsize > 0 && stat_getsize(path, &size, XF_IGNORENOENT) >= 0
 	&& size >= (ALLOC_T)maxlogsize * (ALLOC_T)1024) {
-		snprintf2(old, sizeof(old), "%s.old", path);
+		Xsnprintf(old, sizeof(old), "%s.old", path);
 		if (Xrename(path, old) < 0) VOID_C Xunlink(path);
 	}
 
@@ -94,12 +94,12 @@ va_dcl
 	duperrno = errno;
 
 	VA_START(args, fmt);
-	n = vsnprintf2(buf, sizeof(buf), fmt, args);
+	n = Xvsnprintf(buf, sizeof(buf), fmt, args);
 	va_end(args);
 
 	cp = (log_errno > 0) ? Xstrerror(log_errno) : NULL;
 	if (cp && n < strsize(buf))
-		snprintf2(&(buf[n]), (int)sizeof(buf) - n, " (%s)", cp);
+		Xsnprintf(&(buf[n]), (int)sizeof(buf) - n, " (%s)", cp);
 
 	if (log_errno >= 0) {
 		memcpy(log_buf, buf, sizeof(log_buf));
@@ -132,11 +132,11 @@ va_dcl
 #endif
 	if ((fp = log_open())) {
 		if (isatty(fp -> fd)) n = 0;
-		else n = snprintf2(tmp, sizeof(tmp),
+		else n = Xsnprintf(tmp, sizeof(tmp),
 			"%s:%s(%d):", log_filename, log_function, log_line);
-		snprintf2(&(tmp[n]), (int)sizeof(tmp) - n, "%s\n", buf);
-		Xfputs(tmp, fp);
-		Xfclose(fp);
+		Xsnprintf(&(tmp[n]), (int)sizeof(tmp) - n, "%s\n", buf);
+		VOID_C Xfputs(tmp, fp);
+		VOID_C Xfclose(fp);
 	}
 
 	errno = duperrno;
@@ -154,8 +154,8 @@ char *log_strerror(VOID_A)
 	return((n > 0) ? Xstrerror(n) : NULL);
 }
 
-VOID log_dump(buf, size, mes)
-u_char *buf;
+static VOID log_dump(buf, size, mes)
+CONST u_char *buf;
 ALLOC_T size;
 CONST char *mes;
 {
@@ -176,7 +176,7 @@ CONST char *mes;
 
 	if (!size) {
 		if (mes) {
-			snprintf2(s, sizeof(s), "%s:(empty)\n", mes);
+			Xsnprintf(s, sizeof(s), "%s:(empty)\n", mes);
 			VOID_C Xfputs(s, fp);
 		}
 
@@ -186,14 +186,14 @@ CONST char *mes;
 	}
 
 	if (mes) {
-		snprintf2(s, sizeof(s), "%s\n", mes);
+		Xsnprintf(s, sizeof(s), "%s\n", mes);
 		VOID_C Xfputs(s, fp);
 	}
 	for (ptr = (ALLOC_T)0; ptr < size; ptr += 16) {
 		len = 0;
 		for (i = 0; i < 16; i++) {
 			if (ptr + i >= size) memcpy(&(s[len]), "  ", 2);
-			else snprintf2(&(s[len]), 2 + 1, "%02x", buf[ptr + i]);
+			else Xsnprintf(&(s[len]), 2 + 1, "%02x", buf[ptr + i]);
 			len += 2;
 			s[len++] = ' ';
 		}
@@ -202,31 +202,29 @@ CONST char *mes;
 		for (i = 0; i < 16; i++) {
 			if (ptr + i >= size) break;
 			c = buf[ptr + i];
-			if (!isprint2(c)) c = '.';
+			if (!Xisprint(c)) c = '.';
 			s[len++] = c;
 		}
 
 		s[len++] = '\n';
-		VOID_C Xfwrite((u_char *)s, len, fp);
+		VOID_C Xfwrite(s, len, fp);
 	}
 
-	Xfclose(fp);
+	VOID_C Xfclose(fp);
 
 	errno = duperrno;
 	log_working = 0;
 }
 
-VOID log_fpdump(lvl, s, fp)
+VOID log_debugfp(lvl, s, fp)
 int lvl;
 CONST char *s;
 XFILE *fp;
 {
 	if (!fp) return;
+	if (++lvl < 0) lvl = 0;
 
-	if (lvl < 0) lvl = 0;
-	else if (++lvl > XF_DEBUGLVL) lvl = XF_DEBUGLVL;
-
+	fp -> dumpfunc = log_dump;
+	fp -> debuglvl = lvl;
 	fp -> debugmes = s;
-	fp -> flags &= ~XF_DEBUGLVL;
-	fp -> flags |= lvl;
 }
