@@ -102,6 +102,7 @@ typedef long	off_t;
 # define	NODNAMLEN
 # define	DNAMESIZE	1
 # define	NOTMGMTOFF
+# define	USEINSYSTMH
 # define	USESTATVFSH
 # define	USESTATVFS_T
 # define	USEMNTTABH
@@ -225,6 +226,7 @@ typedef long	off_t;
 # define	USETERMINFO
 # define	TERMCAPLIB	"-lcurses"
 # endif
+#define	BUGGYMAKE
 #define	USEPID_T
 #define	NOSIGLIST
 #define	NOTZFILEH
@@ -482,7 +484,23 @@ typedef long	off_t;
 #define	USEMANLANG
 #define	BSDINSTALL
 #define	TARUSESPACE
-#define	TERMCAPLIB		"-ltermcap"
+/*
+ *	This is a fake '#if' for obsolete version of Cygwin.
+ *	Will you please define 'OldCygwin' manually on Cygwin.
+ *
+ *	Some old Cygwin has no libncurses, to use libtermcap.
+ *	Latest distribution has no libtermcap, to use libncurses.
+ *	If you use older Cygwin without libncurses,
+ *	you should try to define 'OldCygwin' here and to re-compile.
+ *
+#define	OldCygwin
+ *
+ */
+# if	defined (OldCygwin)
+# define	TERMCAPLIB	"-ltermcap"
+# else
+# define	TERMCAPLIB	"-lncurses"
+# endif
 #define	NOSIGLIST
 #define	DECLERRLIST
 #define	HAVECLINE
@@ -569,6 +587,7 @@ typedef long	off_t;
 #define	USEMNTINFO
 #define	USERE_COMP
 #define	USESETENV
+#define	ULONGIOCTL
 #define	USEMKTIME
 #define	SIGFNCINT
 #define	USEINETATON
@@ -594,6 +613,7 @@ typedef long	off_t;
 # endif
 #define	USERE_COMP
 #define	USESETENV
+#define	ULONGIOCTL
 #define	USEMKTIME
 #define	SIGFNCINT
 #define	USEINETATON
@@ -612,6 +632,7 @@ typedef long	off_t;
 #define	USEFFSTYPE
 #define	USERE_COMP
 #define	USESETENV
+#define	ULONGIOCTL
 #define	USEMKTIME
 #define	SIGFNCINT
 #define	USEINETATON
@@ -641,6 +662,7 @@ typedef long	off_t;
 #define	USEMNTINFO
 #define	USERE_COMP
 #define	USESETENV
+#define	ULONGIOCTL
 #define	USEMKTIME
 #define	USEINETATON
 #include <sys/param.h>
@@ -668,6 +690,7 @@ typedef long	off_t;
 # endif	/* __FreeBSD__ */
 #define	USEREGCOMP
 #define	USESETENV
+#define	ULONGIOCTL
 #define	USEMKTIME
 #define	SIGFNCINT
 #define	USEINETATON
@@ -688,6 +711,7 @@ typedef long	off_t;
 #define	USEFFSTYPE
 #define	USERE_COMP
 #define	USESETENV
+#define	ULONGIOCTL
 #define	USEMKTIME
 #define	SIGFNCINT
 #define	USEINETATON
@@ -709,6 +733,7 @@ typedef long	off_t;
 #define	USEREGCOMP
 #define	USESETENV
 #define	SELECTRWONLY
+#define	ULONGIOCTL
 #define	USEMKTIME
 #define	SIGFNCINT
 #define	USESOCKLEN
@@ -726,6 +751,7 @@ typedef long	off_t;
 #define	USEMOUNTH
 #define	USEMNTINFO
 #define	USESETENV
+#define	ULONGIOCTL
 #define	USEMKTIME
 #define	USEWAITPID
 #define	USESIGPMASK
@@ -814,6 +840,7 @@ typedef long	off_t;
 /* #define BSDINSTCMD	;command name except "install" to install like BSD */
 /* #define TARUSESPACE	;tar(1) uses space to devide file mode from UID */
 /* #define TARFROMPAX	;tar(1) comes from pax(1) */
+/* #define BUGGYMAKE	;make(1) assumes the same timestamp as earlier */
 /* #define CPP7BIT	;cpp(1) cannot through 8bit */
 /* #define CCCOMMAND	;fullpath of suitable cc(1) */
 /* #define EXTENDCCOPT	;additional option on cc(1) */
@@ -911,6 +938,7 @@ typedef long	off_t;
 /* #define NOTERMVAR	;have not termcap variables such as PC, ospeed, etc. */
 /* #define USEUTIME	;use utime() instead of utimes() */
 /* #define USEGETWD	;use getwd() instead of getcwd() */
+/* #define ULONGIOCTL	;the 2nd argument of ioctl() is unsigned long */
 /* #define USEFCNTLOCK	;use fcntl() lock instead of flock() */
 /* #define USELOCKF	;use lockf() instead of flock() */
 /* #define NOFLOCK	;have neither flock() nor lockf() */
