@@ -9,6 +9,7 @@
 #include "smtp.h"
 
 static int NEAR setmyname __P_((CONST char *));
+static VOID NEAR setincapable __P_((VOID_A));
 static int NEAR mhpopd __P_((int, int));
 int main __P_((int, char *CONST []));
 
@@ -20,9 +21,10 @@ CONST char *s;
 	ALLOC_T len;
 
 	if (!s) return(-1);
-	if ((cp = strrchr(s, '/'))) s = ++cp;
+	if ((cp = Xstrrchr(s, '/'))) s = ++cp;
 #ifdef	CYGWIN
-	if ((cp = strchr(s, '.')) && !strpathcmp(cp + 1, "exe")) len = cp - s;
+	if ((cp = Xstrchr(s, '.')) && !strpathcmp(cp + 1, "exe"))
+		len = cp - s;
 	else
 #endif
 	len = strlen(s);
@@ -40,6 +42,29 @@ CONST char *s;
 	return(-1);
 }
 
+static VOID NEAR setincapable(VOID_A)
+{
+	char **argv;
+	ALLOC_T len;
+	int i, n;
+
+	incapableflags = 0;
+	if (!incapable || !*incapable) return;
+	argv = msg_getargv(incapable, (ALLOC_T)-1);
+
+	for (i = 0; argv[i]; i++) {
+		len = strlen(argv[i]);
+		if ((n = auth_getid(argv[i], len)) < 0) {
+			if (mh_protocol != MHP_POP3) continue;
+			if ((n = pop_getincapable(argv[i], len)) < 0) continue;
+		}
+
+		incapableflags |= (1 << n);
+	}
+
+	list_free(argv);
+}
+
 static int NEAR mhpopd(fdin, fdout)
 int fdin, fdout;
 {
@@ -47,26 +72,27 @@ int fdin, fdout;
 	XFILE *fpin, *fpout;
 	int n;
 
-	fpin = Xfdopen(fdout, "r", sockettimeout, XF_CONNECTED, pathsocket);
+	fpin = Xfdopen(fdout, "r", sockettimeout,
+		XF_CRNL | XF_NONBLOCK | XF_CONNECTED, pathsocket);
 	if (!fpin) return(-1);
-	fpout = Xfdopen(fdin, "w",
-		sockettimeout, XF_NOCLOSE | XF_CONNECTED, pathsocket);
+	fpout = Xfdopen(fdin, "w", sockettimeout,
+		XF_CRNL | XF_NONBLOCK | XF_NOCLOSE | XF_CONNECTED, pathsocket);
 	if (!fpout) {
-		Xfclose(fpin);
+		VOID_C Xfclose(fpin);
 		return(-1);
 	}
 
 	mydomain = pwd_gethost();
 	switch (mh_protocol) {
 		case MHP_POP3:
-			log_fpdump(5, "POP3 receive:", fpin);
-			log_fpdump(5, "POP3 send:", fpout);
+			log_debugfp(5, "POP3 receive:", fpin);
+			log_debugfp(5, "POP3 send:", fpout);
 			func = pop_receive;
 			n = pop_greeting(fpout);
 			break;
 		case MHP_SMTP:
-			log_fpdump(5, "SMTP receive:", fpin);
-			log_fpdump(5, "SMTP send:", fpout);
+			log_debugfp(5, "SMTP receive:", fpin);
+			log_debugfp(5, "SMTP send:", fpout);
 			func = smtp_receive;
 			n = smtp_greeting(fpout);
 			break;
@@ -77,11 +103,11 @@ int fdin, fdout;
 	}
 
 	if (n >= 0) while (!(n = (*func)(fpin, fpout)))
-		if (Xfeof(fpin) > 0 || (n = Xfflush(fpout)) < 0) break;
+		if (Xfeof(fpin) > 0 || (n = Xfflush(fpout)) == EOF) break;
 
 	if (n >= 0) fpout -> flags &= ~XF_CONNECTED;
-	Xfclose(fpout);
-	Xfclose(fpin);
+	VOID_C Xfclose(fpout);
+	VOID_C Xfclose(fpin);
 	DEBUG(0, ("Connection closed"));
 	VOID_C wait_all(DISCARDTIMEOUT);
 
@@ -96,10 +122,11 @@ char *CONST argv[];
 
 	conf_init(0);
 	if (setmyname(argv[0]) < 0) {
-		fprintf(stderr, "%s: Illegal program name\n", argv[0]);
+		Xfprintf(Xstderr, "%s: Illegal program name\n", argv[0]);
 		return(1);
 	}
 	if ((n = conf_args(argc, argv)) <= 0) return(-n);
+	stream_isnfsfunc = fsys_isnfs;
 	log_init();
 	if (sock_issocket(STDIN_FILENO) && sock_issocket(STDOUT_FILENO))
 		isinetd = isdaemon = 1;
@@ -107,6 +134,7 @@ char *CONST argv[];
 	if (conf_load(NULL, XF_INHEAD) < 0) return(1);
 	if (pid_check() < 0) return(1);
 	if (!isinetd && !interactive) daemonize = 1;
+	setincapable();
 
 	if (interactive && term_init() < 0) return(1);
 	if (daemonize && Xdaemon(0, 0) < 0) return(1);
