@@ -4,11 +4,8 @@
  *	MD5 message digest in RFC1321
  */
 
-#include "machine.h"
-#include <sys/types.h>
+#include "headers.h"
 #include <limits.h>
-#include <string.h>
-#include <errno.h>
 
 #ifndef	BITSPERBYTE
 #define	BITSPERBYTE		CHAR_BIT
@@ -276,7 +273,7 @@ int md5_fencode(buf, sizep, fp, func)
 u_char *buf;
 ALLOC_T *sizep;
 VOID_P fp;
-int (*func)__P_((u_char *, ALLOC_T, VOID_P));
+int (*func)__P_((char *, ALLOC_T, VOID_P));
 {
 	md5_t md5;
 	u_char tmp[MD5_FILBUFSIZ];
@@ -284,7 +281,8 @@ int (*func)__P_((u_char *, ALLOC_T, VOID_P));
 
 	md5_init(&md5);
 	if (fp) for (;;) {
-		if ((n = (*func)(tmp, sizeof(tmp), fp)) < 0) return(-1);
+		if ((n = (*func)((char *)tmp, sizeof(tmp), fp)) < 0)
+			return(-1);
 		else if (!n) break;
 		md5_add(&md5, tmp, n);
 	}
