@@ -37,7 +37,6 @@ int flags;
 	return(new);
 }
 
-
 char *msg_getline(fp, lenp, flags)
 XFILE *fp;
 ALLOC_T *lenp;
@@ -74,7 +73,7 @@ int flags;
 
 		c = Xfgetc(fp);
 		VOID_C Xungetc(c, fp);
-		if (c == EOF || !isblank2(c)) break;
+		if (c == EOF || !Xisblank(c)) break;
 	}
 
 	if (buf && buf != nullline) {
@@ -94,8 +93,8 @@ CONST char *s;
 XFILE *fp;
 {
 	if (!s) s = nullstr;
-	if (*s == '.' && Xfputc('.', fp) < 0) return(-1);
-	if (Xfputs(s, fp) < 0 || Xfputs("\r\n", fp) < 0) return(-1);
+	if (*s == '.' && Xfputc('.', fp) == EOF) return(-1);
+	if (Xfputs(s, fp) == EOF || Xfputs("\n", fp) == EOF) return(-1);
 
 	return(0);
 }
@@ -108,7 +107,7 @@ int flags;
 	char *cp;
 	ALLOC_T len;
 
-	if (!(cp = strchr(buf, ':'))) {
+	if (!(cp = Xstrchr(buf, ':'))) {
 		if (!(flags & XF_IGNOREERR))
 			ERROR0(("%s: Unexpected end of field", buf));
 		return(NULL);
@@ -121,7 +120,7 @@ int flags;
 		return(NULL);
 	}
 
-	while (isblank2(*cp)) cp++;
+	while (Xisblank(*cp)) cp++;
 	if (lenp) *lenp = len;
 
 	return(cp);
@@ -143,17 +142,18 @@ va_dcl
 	int n;
 
 	VA_START(args, fmt);
-	n = vsnprintf2(buf, sizeof(buf), fmt, args);
-	n += snprintf2(&(buf[n]), (int)sizeof(buf) - n, "\r\n");
+	n = Xvsnprintf(buf, sizeof(buf), fmt, args);
 	va_end(args);
+	if (n < 0) return(-1);
+	if (n < sizeof(buf)) buf[n++] = '\n';
 
-	return(Xfwrite((u_char *)buf, n, fp));
+	return((Xfwrite(buf, n, fp) < n) ? -1 : 0);
 }
 
 int msg_sendeom(fp)
 XFILE *fp;
 {
-	return(Xfputs(".\r\n", fp));
+	return((Xfputs(".\n", fp) == EOF) ? -1 : 0);
 }
 
 char **msg_getargv(s, size)
@@ -170,15 +170,15 @@ ALLOC_T size;
 	if (!s) return(argv);
 
 	if (size == (ALLOC_T)-1) size = strlen(s);
-	for (ptr = (ALLOC_T)0; ptr < size; ptr++) if (!isblank2(s[ptr])) break;
+	for (ptr = (ALLOC_T)0; ptr < size; ptr++) if (!Xisblank(s[ptr])) break;
 
 	while (ptr < size) {
 		cp = &(s[ptr]);
-		while (++ptr < size) if (isblank2(s[ptr])) break;
+		while (++ptr < size) if (Xisblank(s[ptr])) break;
 
 		if (!(argv = list_add(argv, argc++, cp, &(s[ptr]) - cp)))
 			return(NULL);
-		while (++ptr < size) if (!isblank2(s[ptr])) break;
+		while (++ptr < size) if (!Xisblank(s[ptr])) break;
 	}
 
 	return(argv);
@@ -198,7 +198,7 @@ ALLOC_T len;
 	*buf = '\0';
 	for (ptr = (ALLOC_T)0; ptr < len; ptr++) {
 		if (cp - buf > size) break;
-		n = snprintf2(cp, size - (cp - buf), "%<02x", (int)(s[ptr]));
+		n = Xsnprintf(cp, size - (cp - buf), "%<02x", (int)(s[ptr]));
 		cp += n;
 	}
 }
