@@ -35,17 +35,17 @@ int msgno;
 	char *home;
 	int n;
 
-	if (*spooldir == '/') n = snprintf2(path, size, "%s", spooldir);
+	if (*spooldir == '/') n = Xsnprintf(path, size, "%s", spooldir);
 	else if (!(home = pwd_gethome(geteuid()))) return(-1);
 	else {
-		n = snprintf2(path, size, "%s", home);
+		n = Xsnprintf(path, size, "%s", home);
 		if (n < (int)size && spooldir && *spooldir)
-			n += snprintf2(&(path[n]), size - n, "/%s", spooldir);
+			n += Xsnprintf(&(path[n]), size - n, "/%s", spooldir);
 	}
 
 	if (folder && *folder)
-		n += snprintf2(&(path[n]), size - n, "/%s", folder);
-	if (msgno >= 0) n += snprintf2(&(path[n]), size - n, "/%d", msgno);
+		n += Xsnprintf(&(path[n]), size - n, "/%s", folder);
+	if (msgno >= 0) n += Xsnprintf(&(path[n]), size - n, "/%d", msgno);
 
 	return(n);
 }
@@ -60,7 +60,7 @@ CONST char *folder;
 	if ((n = mh_genpath(path, size, NULL, -1)) < 0) return(-1);
 	if (Xmkdir(path, folderprotect) < 0) return(-1);
 
-	n += snprintf2(&(path[n]), size - n, "/%s", folder);
+	n += Xsnprintf(&(path[n]), size - n, "/%s", folder);
 	if (Xmkdir(path, folderprotect) < 0) return(-1);
 
 	return(n);
@@ -87,12 +87,12 @@ ALLOC_T size;
 		}
 		if ((cp = msg_getfield(buf, &len, flags))
 		&& !Xstrncasecmp(buf, field, len) && !(field[len])) {
-			snprintf2(val, size, "%s", cp);
+			Xsnprintf(val, size, "%s", cp);
 			Xfree(buf);
 			break;
 		}
 	}
-	Xfclose(fp);
+	VOID_C Xfclose(fp);
 
 	if (!buf) return(0);
 
@@ -111,9 +111,9 @@ CONST char *file, *field, *line;
 	if (!(fpin = Xfopen(file, "r", 0, XF_IGNORENOENT)))
 		if (errno != ENOENT) return(-1);
 
-	snprintf2(path, sizeof(path), "%s%s", file, (fpin) ? ".bak" : nullstr);
+	Xsnprintf(path, sizeof(path), "%s%s", file, (fpin) ? ".bak" : nullstr);
 	if (!(fpout = Xfopen(path, "w", O_EXCL, 0))) {
-		Xfclose(fpin);
+		VOID_C Xfclose(fpin);
 		return(-1);
 	}
 
@@ -128,30 +128,30 @@ CONST char *file, *field, *line;
 		}
 		else cp = buf;
 
-		n = Xfputs(cp, fpout);
+		n = (Xfputs(cp, fpout) == EOF) ? -1 : 0;
 		Xfree(buf);
 		if (n < 0) break;
 	}
-	if (n >= 0 && line) n = Xfputs(line, fpout);
+	if (n >= 0 && line) n = (Xfputs(line, fpout) == EOF) ? -1 : 0;
 
-	if (n < 0 || Xfflush(fpout) < 0) {
-		Xunlink(fpout -> path);
-		Xfclose(fpout);
-		Xfclose(fpin);
+	if (n < 0 || Xfflush(fpout) == EOF) {
+		VOID_C Xunlink(fpout -> path);
+		VOID_C Xfclose(fpout);
+		VOID_C Xfclose(fpin);
 		return(-1);
 	}
 
 	if (fpin) {
-		Xfclose(fpout);
+		VOID_C Xfclose(fpout);
 		if (Xrename(path, fpin -> path) < 0) {
-			Xunlink(path);
-			Xfclose(fpin);
+			VOID_C Xunlink(path);
+			VOID_C Xfclose(fpin);
 			return(-1);
 		}
 		fpout = fpin;
 	}
 
-	Xfclose(fpout);
+	VOID_C Xfclose(fpout);
 
 	return(0);
 }
@@ -165,9 +165,9 @@ CONST char *folder;
 	if (!folder || !*folder || !sequence || !*sequence) return(-1);
 
 	if ((n = mh_genpath(path, sizeof(path), folder, -1)) < 0) return(-1);
-	snprintf2(&(path[n]), (int)sizeof(path) - n, "/%s", sequence);
+	Xsnprintf(&(path[n]), (int)sizeof(path) - n, "/%s", sequence);
 	if ((n = mh_getfield(path, curstr, tmp, sizeof(tmp))) < 0) return(-1);
-	if (!n || !isdigit2(*tmp) || (n = atoi(tmp)) < 0) n = 0;
+	if (!n || !Xisdigit(*tmp) || (n = atoi(tmp)) < 0) n = 0;
 
 	return(n);
 }
@@ -182,8 +182,8 @@ int cur;
 	if (cur < 0) return(-1);
 	if (!folder || !*folder || !sequence || !*sequence) return(-1);
 	if ((n = mh_genpath(path, sizeof(path), folder, -1)) < 0) return(-1);
-	snprintf2(&(path[n]), (int)sizeof(path) - n, "/%s", sequence);
-	snprintf2(tmp, sizeof(tmp), "%s: %d\n", curstr, cur);
+	Xsnprintf(&(path[n]), (int)sizeof(path) - n, "/%s", sequence);
+	Xsnprintf(tmp, sizeof(tmp), "%s: %d\n", curstr, cur);
 
 	return(mh_setfield(path, curstr, tmp));
 }
@@ -211,7 +211,7 @@ CONST char *folder;
 	if (!folder || !*folder) folder = inboxdir;
 
 	if (mh_genpath(path, sizeof(path), context, -1) < 0) return(-1);
-	snprintf2(tmp, sizeof(tmp), "%s: %s\n", curfolderstr, folder);
+	Xsnprintf(tmp, sizeof(tmp), "%s: %s\n", curfolderstr, folder);
 
 	return(mh_setfield(path, curfolderstr, tmp));
 }
@@ -300,9 +300,9 @@ int seq;
 
 		if ((last = mh_getlast(buf)) >= 0) for (i = 0; i < n; i++) {
 			if (list[i] <= seq) continue;
-			snprintf2(&(src[slen]), (int)sizeof(src) - slen,
+			Xsnprintf(&(src[slen]), (int)sizeof(src) - slen,
 				"/%d", list[i]);
-			snprintf2(&(dest[dlen]), (int)sizeof(dest) - dlen,
+			Xsnprintf(&(dest[dlen]), (int)sizeof(dest) - dlen,
 				"/%d", last + 1);
 			if (Xrename(src, dest) < 0) continue;
 
@@ -313,7 +313,7 @@ int seq;
 
 		if (ischild) break;
 	}
-	Xfclose(fp);
+	VOID_C Xfclose(fp);
 
 	if (ischild) {
 		pid_unlink();
@@ -338,7 +338,7 @@ ALLOC_T size;
 	if (!draftdir || !*draftdir) {
 		if (mh_genpath(path, sizeof(path), draftstr, -1) < 0)
 			return(NULL);
-		snprintf2(file, size, "%s", draftstr);
+		Xsnprintf(file, size, "%s", draftstr);
 	}
 	else {
 		n = mh_mkfolder(path, sizeof(path), draftdir);
@@ -346,8 +346,8 @@ ALLOC_T size;
 
 		if ((last = mh_getlast(draftdir)) < 0) return(NULL);
 		last++;
-		snprintf2(&(path[n]), (int)sizeof(path) - n, "/%d", last);
-		snprintf2(file, size, "%s/%d", draftdir, last);
+		Xsnprintf(&(path[n]), (int)sizeof(path) - n, "/%d", last);
+		Xsnprintf(file, size, "%s/%d", draftdir, last);
 	}
 
 	n = umask((msgprotect ^ 0777) & 0777);
@@ -365,7 +365,7 @@ int timeout;
 	int i, n, fd;
 
 	if ((n = mh_genpath(path, sizeof(path), NULL, -1)) < 0) return(-1);
-	snprintf2(&(path[n]), (int)sizeof(path) - n, "/.%s.lck", s);
+	Xsnprintf(&(path[n]), (int)sizeof(path) - n, "/.%s.lck", s);
 
 	for (i = 0; timeout <= 0 || i < timeout * 10; i++) {
 		if (sig_check(1) < 0) return(-1);
@@ -374,7 +374,7 @@ int timeout;
 			O_WRONLY | O_CREAT | O_EXCL, 0666, XF_IGNOREERR);
 		if (fd >= 0) {
 			sig_push(path);
-			Xclose(fd, path);
+			VOID_C Xclose(fd, path);
 			return(0);
 		}
 		else if (errno != EEXIST) break;
@@ -394,7 +394,7 @@ CONST char *s;
 	int n;
 
 	if ((n = mh_genpath(path, sizeof(path), NULL, -1)) < 0) return(-1);
-	snprintf2(&(path[n]), (int)sizeof(path) - n, "/.%s.lck", s);
+	Xsnprintf(&(path[n]), (int)sizeof(path) - n, "/.%s.lck", s);
 	sig_pop(path);
 
 	return(Xunlink(path));
@@ -409,16 +409,16 @@ int timeout;
 {
 	char *cp, *prog, **args, **list, path[MAXPATHLEN], buf[MAXLINEBUF + 1];
 	u_short *pat;
-	ALLOC_T ptr;
+	ALLOC_T ptr, len;
 	p_id_t pid;
 	time_t last;
 	u_char uc;
 	int n, argc, fd, status;
 
 	if (!proc || !*proc) return(0);
-	else if (*proc == '/') snprintf2(path, sizeof(path), "%s", proc);
-	else snprintf2(path, sizeof(path), "%s/%s", mhbindir, proc);
-	if ((prog = strrchr(path, '/'))) prog++;
+	else if (*proc == '/') Xsnprintf(path, sizeof(path), "%s", proc);
+	else Xsnprintf(path, sizeof(path), "%s/%s", mhbindir, proc);
+	if ((prog = Xstrrchr(path, '/'))) prog++;
 	else prog = path;
 
 	argc = list_count(argv);
@@ -436,7 +436,7 @@ int timeout;
 	if (!prompt || !auth_passwd) pat = NULL;
 	else {
 		for (ptr = strlen(prompt); ptr; ptr--)
-			if (!isspace2(prompt[ptr - 1])) break;
+			if (!Xisspace(prompt[ptr - 1])) break;
 		pat = (ptr) ? wild_init(prompt, ptr) : NULL;
 	}
 
@@ -480,7 +480,7 @@ int timeout;
 	else for (;;) {
 		ptr = (ALLOC_T)0;
 		for (;;) {
-			n = Xread(fd, &uc, sizeof(uc), 0, NULL);
+			n = Xread(fd, (char *)&uc, sizeof(uc), 0, NULL);
 			if (n <= 0 || uc == '\r' || uc == '\n') break;
 			buf[ptr] = uc;
 			if (ptr < strsize(buf)) ptr++;
@@ -519,23 +519,29 @@ int timeout;
 		if (list) list = list_add(list, argc++, buf, ptr);
 		if (!pat) continue;
 
-		for (; ptr; ptr--) if (!isspace2(buf[ptr - 1])) break;
-		for (cp = buf; isspace2(*cp); cp++) ptr--;
+		for (; ptr; ptr--) if (!Xisspace(buf[ptr - 1])) break;
+		for (cp = buf; Xisspace(*cp); cp++) ptr--;
 		if (wild_match(cp, ptr, pat) <= 0) continue;
 
 		uc = '\r';
-		n = Xwrite(fd,
-			(u_char *)auth_passwd, strlen(auth_passwd), 0, prog);
-		if (n < 0) break;
-		n = Xwrite(fd, (u_char *)&uc, sizeof(uc), 0, prog);
-		if (n < 0) break;
+		len = strlen(auth_passwd);
+		n = Xwrite(fd, auth_passwd, len, 0, prog);
+		if (n < (int)len) {
+			n = -1;
+			break;
+		}
+		n = Xwrite(fd, (char *)&uc, sizeof(uc), 0, prog);
+		if (n < (int)sizeof(uc)) {
+			n = -1;
+			break;
+		}
 
 		DEBUG(2, ("%s: Password sent", prog));
 	}
 
 	Xfree(pat);
 	wait_cancel(pid);
-	if (fd >= 0) Xclose(fd, prog);
+	if (fd >= 0) VOID_C Xclose(fd, prog);
 
 	if (!n) DEBUG(2, ("%s: Exit status 0", prog));
 	else if (n < 0) listp = NULL;
