@@ -6,15 +6,12 @@
 
 #include "mhpopd.h"
 #include <pwd.h>
-#include <time.h>
-#include <sys/stat.h>
-#include <sys/param.h>
 
-#define	PASSWD_MINLEN	6
-#define	PASSWD_BUFSIZ	127
+#define	PASSWD_MINLEN		6
+#define	PASSWD_BUFSIZ		127
 
 #ifndef	VER
-#define	VER		"0.00"
+#define	VER			"0.00"
 #endif
 
 int main __P_((int, char *CONST []));
@@ -100,7 +97,7 @@ char *CONST argv[];
 	}
 
 	fprintf(fp, "%s\n", buf);
-	fclose(fp);
+	VOID_C fclose(fp);
 	VOID_C chmod(path, 0600);
 
 	fprintf(stderr, "Written password in \"%s\"\n", path);
