@@ -6,16 +6,8 @@
 
 #define	__MH_PRIMAL__
 #include "mhpopd.h"
-
-#include <sys/param.h>
 #include "version.h"
 
-#ifndef	NOUNISTDH
-#include <unistd.h>
-#endif
-#ifndef	NOSTDLIBH
-#include <stdlib.h>
-#endif
 #ifdef	USESELECTH
 #include <sys/select.h>
 #endif
@@ -58,6 +50,7 @@ char *CONST argv[];
 	char *cp;
 	int n;
 
+	printf("s:__VERMAJ__:%d:\n", MH);
 	if (!(cp = strchr(version, ' '))) cp = version;
 	else while (*cp == ' ') cp++;
 	for (n = 0; cp[n]; n++) if (cp[n] == ' ') break;
@@ -76,6 +69,12 @@ char *CONST argv[];
 	printf("s:__OBJLIST__:$(OBJS):\n");
 	printf("s:__DEFRC__:'\"'$(DEFRC)'\"':\n");
 
+#ifdef	BUGGYMAKE
+	printf("s:__SLEEP__::\n");
+#else
+	printf("s:__SLEEP__:#:\n");
+#endif
+	printf("s:__DJGPP1__:#:\n");
 	printf("s:__ECHO__:echo:\n");
 	printf("s:__COPY__:cp:\n");
 	printf("s:__RM__:rm -f:\n");
@@ -120,6 +119,12 @@ char *CONST argv[];
 		printf("s:__HOSTCC__:$(CC):\n");
 		printf("s:__HOSTCCOPTIONS__:%s:\n", EXTENDCCOPT);
 	}
+#if	defined (DEFFDSETSIZE) && defined (FD_SETSIZE)
+	if (FD_SETSIZE < MAXOPENFILE)
+		printf("s:__FDSETSIZE__:-DFD_SETSIZE=%d:\n", MAXOPENFILE);
+	else
+#endif
+	printf("s:__FDSETSIZE__::\n");
 	printf("s:__MEM__::\n");
 #ifdef	CCOUTOPT
 	printf("s:__OUT__:%s:\n", CCOUTOPT);
@@ -152,6 +157,7 @@ char *CONST argv[];
 #else
 	printf("s:__PREFIXOPTION__:-c:\n");
 #endif
+	printf("s:[\t ]*$::\n");
 	printf("/^[\t ][\t ]*-*\\$(RM) *$/d\n");
 
 	return(0);
