@@ -6,7 +6,6 @@
 
 #include "mhpopd.h"
 #include "fileio.h"
-#include <signal.h>
 
 static int NEAR pid_filename __P_((char *, ALLOC_T));
 
@@ -29,13 +28,13 @@ ALLOC_T size;
 			if (!(cp = pwd_gethome(uid))) return(-1);
 		}
 	}
-	n = snprintf2(path, size, "%s", cp);
+	n = Xsnprintf(path, size, "%s", cp);
 	if (Xmkdir(path, 0755) < 0) return(-1);
 	if (subdir && *subdir) {
-		n += snprintf2(&(path[n]), size - n, "/%s", subdir);
+		n += Xsnprintf(&(path[n]), size - n, "/%s", subdir);
 		if (Xmkdir(path, 0755) < 0) return(-1);
 	}
-	snprintf2(&(path[n]), size - n, "/%s.pid", myname);
+	Xsnprintf(&(path[n]), size - n, "/%s.pid", myname);
 
 	return(0);
 }
@@ -53,8 +52,8 @@ int pid_check(VOID_A)
 		n = -1;
 	}
 	else {
-		n = Xfread((u_char *)buf, strsize(buf), fp);
-		Xfclose(fp);
+		n = Xfread(buf, strsize(buf), fp);
+		VOID_C Xfclose(fp);
 	}
 
 	if (n >= 0) {
@@ -83,16 +82,16 @@ int pid_create(VOID_A)
 	fp = Xfopen(path, "w", O_EXCL, 0);
 	VOID_C umask(n);
 	if (!fp) {
-		Xunlink(path);
+		VOID_C Xunlink(path);
 		return(-1);
 	}
 
-	n = snprintf2(buf, sizeof(buf), "%d\n", getpid());
-	n = Xfwrite((u_char *)buf, n, fp);
-	if (n >= 0) n = Xfflush(fp);
-	Xfclose(fp);
+	n = Xsnprintf(buf, sizeof(buf), "%d\n", getpid());
+	n = (Xfwrite(buf, n, fp) < n) ? -1 : 0;
+	if (n >= 0) n = (Xfflush(fp) == EOF) ? -1 : 0;
+	VOID_C Xfclose(fp);
 
-	if (n < 0) Xunlink(path);
+	if (n < 0) VOID_C Xunlink(path);
 
 	return(n);
 }
