@@ -4,15 +4,15 @@
  *	header for POP3
  */
 
-#define	POP_OK		"+OK"
-#define	POP_ERR		"-ERR"
-#define	POP_MAXBUF	1024
-#define	POP_MAXARG	40
-#define	POP_STAT_AUTH	0
-#define	POP_STAT_USER	1
-#define	POP_STAT_TRANS	2
-#define	POP_STAT_UPDATE	3
-#define	POP_XUIDL	"X-UIDL:"
+#define	POP_OK			"+OK"
+#define	POP_ERR			"-ERR"
+#define	POP_MAXBUF		1024
+#define	POP_MAXARG		40
+#define	POP_STAT_AUTH		0
+#define	POP_STAT_USER		1
+#define	POP_STAT_TRANS		2
+#define	POP_STAT_UPDATE		3
+#define	POP_XUIDL		"X-UIDL:"
 
 typedef struct _pop3_t {
 	CONST char *folder;
@@ -21,7 +21,7 @@ typedef struct _pop3_t {
 	char *uidl;
 	u_int flags;
 } pop3_t;
-#define	POP_DELETED	000001
+#define	POP_DELETED		000001
 
 extern char pop_okstr[];
 extern char pop_errstr[];
@@ -38,9 +38,13 @@ extern int pop_fetch __P_((VOID_A));
 extern int pop_gettotal __P_((ALLOC_T *));
 extern int pop_getmsgno __P_((CONST char *));
 extern XFILE *pop_openmsg __P_((int));
+extern char *pop_readmsg __P_((XFILE *, ALLOC_T *));
+extern VOID pop_closemsg __P_((XFILE *));
 extern int pop_update __P_((VOID_A));
 
 /* pop3recv.c */
+extern int pop_getincapable __P_((CONST char *, ALLOC_T len));
+extern int pop_incapable __P_((CONST char *));
 extern int pop_receive __P_((XFILE *, XFILE *));
 
 /* pop3send.c */
