@@ -23,11 +23,16 @@ typedef struct _pop3cmd_t {
 #define	POP_USER		000002
 #define	POP_TRANS		000004
 #define	POP_KEEPSPACE		000010
+#define	POP_INCAPABLE		000020
+#define	POP_SASL		000040
 #define	popstat(n)		(pop3cmdlist[n].flags & POP_STAT)
 #define	DEFCMD(i,c,n,x,f)	{i, strsize(i), c, n, x, f}
 
 static int lastmsg = -1;
 
+static int NEAR pop_getid __P_((CONST char *, ALLOC_T, int));
+static int NEAR pop_id2incapableid __P_((int));
+static int NEAR pop_incapableid __P_((int));
 static int NEAR pop_quit __P_((char *CONST *, XFILE *fp));
 static int NEAR pop_user __P_((char *CONST *, XFILE *fp));
 static int NEAR pop_pass __P_((char *CONST *, XFILE *fp));
@@ -42,12 +47,13 @@ static int NEAR pop_top __P_((char *CONST *, XFILE *fp));
 static int NEAR pop_uidl __P_((char *CONST *, XFILE *fp));
 static int NEAR pop_auth __P_((char *CONST *, XFILE *fp));
 static int NEAR pop_last __P_((char *CONST *, XFILE *fp));
+static int NEAR pop_capa __P_((char *CONST *, XFILE *fp));
 
 static CONST pop3cmd_t pop3cmdlist[] = {
 	DEFCMD("QUIT", pop_quit, 0, 0, POP_AUTH | POP_USER | POP_TRANS),
-	DEFCMD("USER", pop_user, 1, 1, POP_AUTH),
+	DEFCMD("USER", pop_user, 1, 1, POP_AUTH | POP_INCAPABLE),
 	DEFCMD("PASS", pop_pass, 1, 1, POP_USER | POP_KEEPSPACE),
-	DEFCMD("APOP", pop_apop, 2, 2, POP_AUTH),
+	DEFCMD("APOP", pop_apop, 2, 2, POP_AUTH | POP_INCAPABLE),
 	DEFCMD("STAT", pop_stat, 0, 0, POP_TRANS),
 	DEFCMD("LIST", pop_list, 0, 1, POP_TRANS),
 	DEFCMD("RETR", pop_retr, 1, 1, POP_TRANS),
@@ -56,12 +62,76 @@ static CONST pop3cmd_t pop3cmdlist[] = {
 	DEFCMD("RSET", pop_rset, 0, 0, POP_TRANS),
 	DEFCMD("TOP", pop_top, 2, 2, POP_TRANS),
 	DEFCMD("UIDL", pop_uidl, 0, 1, POP_TRANS),
-	DEFCMD("AUTH", pop_auth, 1, 2, POP_AUTH),
+	DEFCMD("AUTH", pop_auth, 0, 2, POP_AUTH | POP_INCAPABLE | POP_SASL),
 	DEFCMD("LAST", pop_last, 0, 0, POP_TRANS),
+	DEFCMD("CAPA", pop_capa, 0, 0, POP_AUTH | POP_USER | POP_TRANS),
 };
 #define	POP3CMDLISTSIZ		arraysize(pop3cmdlist)
 
 
+static int NEAR pop_getid(s, len, flags)
+CONST char *s;
+ALLOC_T len;
+int flags;
+{
+	int i;
+
+	if (len == (ALLOC_T)-1) len = strlen(s);
+	for (i = 0; i < POP3CMDLISTSIZ; i++) {
+		if (len != pop3cmdlist[i].len) continue;
+		if (Xstrncasecmp(s, pop3cmdlist[i].ident, len)) continue;
+
+		if (!flags || (flags & pop3cmdlist[i].flags)) return(i);
+		break;
+	}
+
+	return(-1);
+}
+
+static int NEAR pop_id2incapableid(n)
+int n;
+{
+	int val;
+
+	if (n < 0 || n >= POP3CMDLISTSIZ) return(-1);
+	if (!(pop3cmdlist[n].flags & POP_INCAPABLE)) return(-1);
+	val = auth_getmaxid();
+	while (--n >= 0) if (pop3cmdlist[n].flags & POP_INCAPABLE) val++;
+
+	return(val);
+}
+
+int pop_getincapable(s, len)
+CONST char *s;
+ALLOC_T len;
+{
+	return(pop_id2incapableid(pop_getid(s, len, POP_INCAPABLE)));
+}
+
+static int NEAR pop_incapableid(n)
+int n;
+{
+	int val;
+
+	if (!incapableflags) return(0);
+	val = pop_id2incapableid(n);
+	if (val < 0) return(0);
+	if (incapableflags & (1 << val)) return(1);
+
+	if (!(pop3cmdlist[n].flags & POP_SASL)) return(0);
+	val = auth_getmaxid();
+	n = (1 << val) - 1;
+	if ((incapableflags & n) == n) return(1);
+
+	return(0);
+}
+
+int pop_incapable(s)
+CONST char *s;
+{
+	return(pop_incapableid(pop_getid(s, (ALLOC_T)-1, 0)));
+}
+
 /*ARGSUSED*/
 static int NEAR pop_quit(argv, fp)
 char *CONST *argv;
@@ -217,26 +287,26 @@ XFILE *fp;
 	if ((n = pop_getmsgno(argv[0])) < 0 || !(fpin = pop_openmsg(n)))
 		return(pop_senderror(fp));
 	if (pop_sendok(fp, "%d octets", pop_msglist[n].size) < 0) {
-		Xfclose(fpin);
+		pop_closemsg(fpin);
 		return(-1);
 	}
 
 	thru = -1;
 	if (sock_issocket(fp -> fd)) {
-		Xfflush(fp);
+		VOID_C Xfflush(fp);
 		thru = sock_changeopt(fp -> fd, SCK_THROUGHPUT);
 	}
 	ret = 0;
 	last = (ALLOC_T)-1;
-	for (; (buf = Xfgets(fpin, &len, XF_TRUNC)); Xfree(buf)) {
+	for (; (buf = pop_readmsg(fpin, &len)); Xfree(buf)) {
 		last = len;
 		if ((ret = msg_putline(buf, fp)) < 0) break;
 	}
-	Xfclose(fpin);
+	pop_closemsg(fpin);
 	if (ret >= 0 && last) ret = msg_putline(nullstr, fp);
 	if (ret >= 0) ret = msg_sendeom(fp);
 	if (thru >= 0) {
-		Xfflush(fp);
+		VOID_C Xfflush(fp);
 		thru = sock_changeopt(fp -> fd, SCK_LOWDELAY);
 	}
 
@@ -291,18 +361,18 @@ XFILE *fp;
 	ALLOC_T len, last;
 	int n, max, isbody;
 
-	if (!(argv[1]) || !isdigit2(*(argv[1]))) max = -1;
+	if (!(argv[1]) || !Xisdigit(*(argv[1]))) max = -1;
 	else max = atoi(argv[1]);
 	if ((n = pop_getmsgno(argv[0])) < 0 || !(fpin = pop_openmsg(n)))
 		return(pop_senderror(fp));
 	if (pop_sendok(fp, "Message follows") < 0) {
-		Xfclose(fpin);
+		pop_closemsg(fpin);
 		return(-1);
 	}
 
 	isbody = 0;
 	last = (ALLOC_T)-1;
-	for (; (buf = Xfgets(fpin, &len, XF_TRUNC)); Xfree(buf)) {
+	for (; (buf = pop_readmsg(fpin, &len)); Xfree(buf)) {
 		last = len;
 		if (!isbody) /*EMPTY*/;
 		else if (!max) {
@@ -314,7 +384,7 @@ XFILE *fp;
 		if (msg_putline(buf, fp) < 0) break;
 		if (!isbody && !*buf) isbody++;
 	}
-	Xfclose(fpin);
+	pop_closemsg(fpin);
 	if (last) VOID_C msg_putline(nullstr, fp);
 	if (msg_sendeom(fp) < 0) return(-1);
 	lastmsg = n;
@@ -349,6 +419,17 @@ static int NEAR pop_auth(argv, fp)
 char *CONST *argv;
 XFILE *fp;
 {
+	char *cp, buf[POP_MAXBUF];
+
+	if (!(argv[0])) {
+		if (auth_genlist(buf, sizeof(buf)) < 0) return(-1);
+		if (pop_sendok(fp, "SASL list follows") < 0) return(-1);
+		for (cp = buf; *cp; cp++) if (*cp == ' ') *cp = '\n';
+		VOID_C msg_send(fp, "%s", buf);
+
+		return(msg_sendeom(fp));
+	}
+
 	return(auth_setmech(argv, fp));
 }
 
@@ -364,12 +445,48 @@ XFILE *fp;
 	return(pop_sendok(fp, "%d", lastmsg + 1));
 }
 
+/*ARGSUSED*/
+static int NEAR pop_capa(argv, fp)
+char *CONST *argv;
+XFILE *fp;
+{
+	char *cp, buf[POP_MAXBUF];
+	int len;
+
+	cp = conf_getversion(&len);
+	if (auth_genlist(buf, sizeof(buf)) < 0) return(-1);
+	if (pop_sendok(fp, "Capability list follows") < 0) return(-1);
+
+	/* RFC2449 */
+	VOID_C msg_send(fp, "TOP");
+	if (!pop_incapable("USER")) VOID_C msg_send(fp, "USER");
+	if (!pop_incapable("APOP")) VOID_C msg_send(fp, "APOP");
+	if (!pop_incapable("AUTH") && *buf)
+		VOID_C msg_send(fp, "SASL %s", buf);
+#if	0
+	VOID_C msg_send(fp, "RESP-CODES");
+	VOID_C msg_send(fp, "LOGIN-DELAY %d", POP_LOGINDELAY);
+	VOID_C msg_send(fp, "PIPELINING");
+#endif
+	VOID_C msg_send(fp, "EXPIRE NEVER");
+	VOID_C msg_send(fp, "UIDL");
+	if (pop_status == POP_STAT_TRANS)
+		VOID_C msg_send(fp,
+			"IMPLEMENTATION %s-%-.*s", myname, len, cp);
+#if	0
+	VOID_C msg_send(fp, "STLS");		/* RFC2595 */
+	VOID_C msg_send(fp, "AUTH-RESP-CODE");	/* RFC3206 */
+#endif
+
+	return(msg_sendeom(fp));
+}
+
 int pop_receive(fpin, fpout)
 XFILE *fpin, *fpout;
 {
 	ALLOC_T len, size;
 	char *buf, **argv;
-	int i, n, argc;
+	int i, n, argc, flags;
 
 	for (;;) {
 		if (!(buf = sock_getline(fpin, &size)))
@@ -383,32 +500,24 @@ XFILE *fpin, *fpout;
 	}
 
 	for (len = (ALLOC_T)0; len < size; len++)
-		if (isblank2(buf[len])) break;
-	for (i = 0; i < POP3CMDLISTSIZ; i++) {
-		if (len != pop3cmdlist[i].len) continue;
-		if (Xstrncasecmp(buf, pop3cmdlist[i].ident, len)) continue;
-
-		switch (pop_status) {
-			case POP_STAT_AUTH:
-				if (!(popstat(i) & POP_AUTH))
-					i = POP3CMDLISTSIZ;
-				break;
-			case POP_STAT_USER:
-				if (!(popstat(i) & POP_USER))
-					i = POP3CMDLISTSIZ;
-				break;
-			case POP_STAT_TRANS:
-				if (!(popstat(i) & POP_TRANS))
-					i = POP3CMDLISTSIZ;
-				break;
-			default:
-				break;
-		}
-
-		break;
+		if (Xisblank(buf[len])) break;
+	switch (pop_status) {
+		case POP_STAT_AUTH:
+			flags = POP_AUTH;
+			break;
+		case POP_STAT_USER:
+			flags = POP_USER;
+			break;
+		case POP_STAT_TRANS:
+			flags = POP_TRANS;
+			break;
+		default:
+			flags = 0;
+			break;
 	}
+	i = pop_getid(buf, len, flags);
 
-	if (i >= POP3CMDLISTSIZ) {
+	if (i < 0 || pop_incapableid(i)) {
 		ERROR0(("%-.*s: Unknown command", len, buf));
 		n = pop_sendwarning(fpout,
 			"Unknown command \"%-.*s\"", len, buf);
