@@ -4,86 +4,51 @@
  *	formatted printing module
  */
 
-#include "machine.h"
-#include <stdio.h>
-#include <string.h>
-#include <sys/types.h>
-
-#ifndef	NOUNISTDH
-#include <unistd.h>
-#endif
-
-#ifndef	NOSTDLIBH
-#include <stdlib.h>
-#endif
-
+#include "headers.h"
+#include "depend.h"
 #include "printf.h"
 #include "kctype.h"
-
-#define	BUFUNIT		16
-#define	THDIGIT		3
-#define	STRNULL		"(null)"
-
-#ifdef	USEPID_T
-typedef pid_t	p_id_t;
-#else
-# if	MSDOS
-typedef int	p_id_t;
-# else
-typedef long	p_id_t;
-# endif
-#endif
-
-#ifdef	USELLSEEK
-typedef long long	l_off_t;
-#else
-typedef off_t		l_off_t;
-#endif
+#include "typesize.h"
+#include "string.h"
 
 #ifdef	FD
-# ifndef	_NOKANJICONV
-extern char *newkanjiconv __P_((char *, int, int, int));
-extern int getoutputkcode __P_((VOID_A));
-# endif
-extern char *restorearg __P_((char *));
-#endif	/* FD */
+#include "kconv.h"
+#endif
 
-#ifdef	CODEEUC
-# ifdef	FD
-extern int strlen2 __P_((CONST char *));
-# else
-static int NEAR strlen2 __P_((CONST char *));
-# endif
-#else	/* !CODEEUC */
-#define	strlen2		strlen
-#endif	/* !CODEEUC */
+#define	PRINTBUFUNIT		16
+#define	THDIGIT			3
+#define	NULLSTR			"(null)"
+
+#ifdef	FD
+extern char *restorearg __P_((CONST char *));
+#endif
 
 static int NEAR checkchar __P_((int, printbuf_t *));
 static int NEAR setint __P_((u_long_t, int, printbuf_t *, int, int));
 static int NEAR setstr __P_((CONST char *, printbuf_t *, int, int));
 static int NEAR commonprintf __P_((printbuf_t *, CONST char *, va_list));
 
-char printfflagchar[] = {
+CONST char printfflagchar[] = {
 	'-', '0', '\'',
 #ifndef	MINIMUMSHELL
 	'+', ' ', '<',
 #endif
 	'\0',
 };
-int printfflag[] = {
+CONST int printfflag[] = {
 	VF_MINUS, VF_ZERO, VF_THOUSAND,
 #ifndef	MINIMUMSHELL
 	VF_PLUS, VF_SPACE, VF_STRICTWIDTH,
 #endif
 };
-char printfsizechar[] = {
+CONST char printfsizechar[] = {
 	'l', 'q', 'i',
 #ifndef	MINIMUMSHELL
 	'L', 'C', 'h',
 #endif
 	'\0',
 };
-int printfsize[] = {
+CONST int printfsize[] = {
 	sizeof(long), sizeof(off_t), sizeof(p_id_t),
 #ifndef	MINIMUMSHELL
 	sizeof(l_off_t), sizeof(char), sizeof(short),
@@ -91,18 +56,6 @@ int printfsize[] = {
 };
 
 
-#if	!defined (FD) && defined (CODEEUC)
-static int NEAR strlen2(s)
-CONST char *s;
-{
-	int i, len;
-
-	for (i = len = 0; s[i]; i++, len++) if (isekana(s, i)) i++;
-
-	return(len);
-}
-#endif	/* !FD && CODEEUC */
-
 int getnum(s, ptrp)
 CONST char *s;
 int *ptrp;
@@ -110,7 +63,7 @@ int *ptrp;
 	int i, n;
 
 	n = 0;
-	for (i = *ptrp; isdigit2(s[i]); i++) {
+	for (i = *ptrp; Xisdigit(s[i]); i++) {
 		if (n > MAXTYPE(int) / 10
 		|| (n == MAXTYPE(int) / 10
 		&& s[i] > (char)(MAXTYPE(int) % 10) + '0'))
@@ -140,7 +93,7 @@ printbuf_t *pbufp;
 	char *tmp;
 
 	if (pbufp -> flags & VF_FILE) {
-		if (pbufp -> buf && fputc(n, (FILE *)(pbufp -> buf)) == EOF)
+		if (pbufp -> buf && Xfputc(n, (XFILE *)(pbufp -> buf)) == EOF)
 			return(-1);
 		(pbufp -> ptr)++;
 		return(1);
@@ -152,7 +105,7 @@ printbuf_t *pbufp;
 				pbufp -> buf[pbufp -> ptr] = '\0';
 			return(1);
 		}
-		pbufp -> size += BUFUNIT;
+		pbufp -> size += PRINTBUFUNIT;
 		if ((tmp = (char *)realloc(pbufp -> buf, pbufp -> size)))
 			pbufp -> buf = tmp;
 		else {
@@ -220,28 +173,28 @@ int width, prec;
 		if (prec) num[len++] = '0';
 	}
 	else while (len < arraysize(num)) {
+		if (bit) {
+			c = (u & base);
 #ifdef	MINIMUMSHELL
-		if (!bit) {
-			i = (n % base);
-			if (i < 0) i = -i;
-			i += '0';
-		}
-		else if ((i = (u & base)) < 10) i += '0';
+			c += '0';
 #else
-		if (!bit) {
-			if (pbufp -> flags & VF_UNSIGNED) i = u % base;
-			else if ((i = n % base) < 0) i = -i;
-			i += '0';
-		}
-		else if ((i = (u & base)) < 10) i += '0';
-		else if (cap) i += 'A' - 10;
-		else i += 'a' - 10;
+			c = tohexa(c);
+			if (cap) c = Xtoupper(c);
 #endif
+		}
+		else {
+#ifndef	MINIMUMSHELL
+			if (pbufp -> flags & VF_UNSIGNED) c = (u % base);
+			else
+#endif
+			if ((c = (n % base)) < 0) c = -c;
+			c += '0';
+		}
 
 		if ((pbufp -> flags & VF_THOUSAND)
 		&& (len % (THDIGIT + 1)) == THDIGIT)
 			num[len++] = ',';
-		num[len++] = i;
+		num[len++] = c;
 		if (bit) {
 			u >>= bit;
 			if (!u) break;
@@ -315,12 +268,16 @@ CONST char *s;
 printbuf_t *pbufp;
 int width, prec;
 {
+#ifdef	DEP_KCONV
+	char *cp, *tmp;
+	int n;
+#endif
 	int i, j, c, len, total;
 
 	if (s) len = strlen2(s);
 	else {
-		s = STRNULL;
-		len = strsize(STRNULL);
+		s = NULLSTR;
+		len = strsize(NULLSTR);
 #ifdef	LINUX
 		/* spec. of glibc */
 		if (prec >= 0 && len > prec) len = 0;
@@ -337,11 +294,8 @@ int width, prec;
 	}
 	total += len;
 
-#if	defined (FD) && !defined (_NOKANJICONV)
+#ifdef	DEP_KCONV
 	if (pbufp -> flags & VF_KANJI) {
-		char *cp, *tmp;
-		int n;
-
 		if (!(tmp = (char *)malloc(len * KANAWID + 1))) return(-1);
 
 		n = len;
@@ -387,7 +341,7 @@ int width, prec;
 		}
 	}
 	else
-#endif	/* FD && !_NOKANJICONV */
+#endif	/* DEP_KCONV */
 	for (i = j = 0; i < len; i++, j++) {
 		c = s[j];
 		if (iskanji1(s, j)) {
@@ -424,8 +378,13 @@ printbuf_t *pbufp;
 CONST char *fmt;
 va_list args;
 {
+#ifndef	HAVELONGLONG
+	u_long_t tmp;
+	int hi;
+#endif
 	u_long_t u, mask;
-	char *s, *cp;
+	CONST char *cp;
+	char *s;
 	int i, len, total, base, width, prec;
 
 	if (pbufp -> flags & VF_NEW) {
@@ -445,7 +404,7 @@ va_list args;
 		pbufp -> flags &= (VF_NEW | VF_FILE);
 		width = prec = -1;
 		for (; fmt[i]; i++) {
-			if (!(cp = strchr(printfflagchar, fmt[i]))) break;
+			if (!(cp = Xstrchr(printfflagchar, fmt[i]))) break;
 			pbufp -> flags |= printfflag[cp - printfflagchar];
 		}
 
@@ -466,7 +425,7 @@ va_list args;
 
 		len = sizeof(int);
 		for (; fmt[i]; i++) {
-			if (!(cp = strchr(printfsizechar, fmt[i]))) break;
+			if (!(cp = Xstrchr(printfsizechar, fmt[i]))) break;
 			len = printfsize[cp - printfsizechar];
 		}
 
@@ -477,17 +436,17 @@ va_list args;
 				break;
 			case 'a':
 			case 'k':
-#if	defined (FD) && !defined (_NOKANJICONV)
+#ifdef	DEP_KCONV
 				pbufp -> flags |= VF_KANJI;
 #endif
 /*FALLTHRU*/
 			case 's':
 				cp = s = va_arg(args, char *);
 #ifdef	FD
-				if (fmt[i] == 'a') cp = restorearg(s);
+				if (fmt[i] == 'a') s = restorearg(cp);
 #endif
-				len = setstr(cp, pbufp, width, prec);
-				if (cp != s) free(cp);
+				len = setstr(s, pbufp, width, prec);
+				if (cp != s) free(s);
 				break;
 			case 'c':
 				len = setchar(va_arg(args, int) & 0xff, pbufp);
@@ -524,16 +483,13 @@ va_list args;
 		if (base) {
 #ifndef	HAVELONGLONG
 			if (len > (int)sizeof(u_long_t)) {
-				u_long_t tmp;
-				int hi;
-
 # ifndef	HPUX
 	/*
 	 * HP-UX always pushes arguments from lowest to uppermost,
 	 * in spite of the CPU endian.
 	 */
 				tmp = 0x5a;
-				cp = (char *)(&tmp);
+				cp = (CONST char *)(&tmp);
 				if (*cp != 0x5a) {
 					hi = va_arg(args, u_int);
 					len -= (int)sizeof(u_int);
@@ -600,7 +556,8 @@ va_list args;
 	return(total);
 }
 
-int vasprintf2(sp, fmt, args)
+#ifndef	MINIMUMSHELL
+int Xvasprintf(sp, fmt, args)
 char **sp;
 CONST char *fmt;
 va_list args;
@@ -616,32 +573,29 @@ va_list args;
 	return(n);
 }
 
-#ifdef	USESTDARGH
+# ifdef	USESTDARGH
 /*VARARGS2*/
-int asprintf2(char **sp, CONST char *fmt, ...)
-#else
+int Xasprintf(char **sp, CONST char *fmt, ...)
+# else
 /*VARARGS2*/
-int asprintf2(sp, fmt, va_alist)
+int Xasprintf(sp, fmt, va_alist)
 char **sp;
 CONST char *fmt;
 va_dcl
-#endif
+# endif
 {
 	va_list args;
-	printbuf_t pbuf;
 	int n;
 
-	if (!sp) return(-1);
-	pbuf.flags = VF_NEW;
 	VA_START(args, fmt);
-	n = commonprintf(&pbuf, fmt, args);
+	n = Xvasprintf(sp, fmt, args);
 	va_end(args);
-	*sp = pbuf.buf;
 
 	return(n);
 }
+#endif	/* !MINIMUMSHELL */
 
-int vsnprintf2(s, size, fmt, args)
+int Xvsnprintf(s, size, fmt, args)
 char *s;
 int size;
 CONST char *fmt;
@@ -659,10 +613,10 @@ va_list args;
 
 #ifdef	USESTDARGH
 /*VARARGS3*/
-int snprintf2(char *s, int size, CONST char *fmt, ...)
+int Xsnprintf(char *s, int size, CONST char *fmt, ...)
 #else
 /*VARARGS3*/
-int snprintf2(s, size, fmt, va_alist)
+int Xsnprintf(s, size, fmt, va_alist)
 char *s;
 int size;
 CONST char *fmt;
@@ -670,56 +624,62 @@ va_dcl
 #endif
 {
 	va_list args;
-	printbuf_t pbuf;
 	int n;
 
-	if (size < 0) return(-1);
-	pbuf.buf = s;
-	pbuf.size = size;
-	pbuf.flags = 0;
 	VA_START(args, fmt);
-	n = commonprintf(&pbuf, fmt, args);
+	n = Xvsnprintf(s, size, fmt, args);
 	va_end(args);
 
 	return(n);
 }
 
+int Xvfprintf(fp, fmt, args)
+XFILE *fp;
+CONST char *fmt;
+va_list args;
+{
+	printbuf_t pbuf;
+
+	pbuf.buf = (char *)fp;
+	pbuf.flags = VF_FILE;
+
+	return(commonprintf(&pbuf, fmt, args));
+}
+
 #ifdef	USESTDARGH
 /*VARARGS2*/
-int fprintf2(FILE *fp, CONST char *fmt, ...)
+int Xfprintf(XFILE *fp, CONST char *fmt, ...)
 #else
 /*VARARGS2*/
-int fprintf2(fp, fmt, va_alist)
-FILE *fp;
+int Xfprintf(fp, fmt, va_alist)
+XFILE *fp;
 CONST char *fmt;
 va_dcl
 #endif
 {
 	va_list args;
-	printbuf_t pbuf;
 	int n;
 
-	pbuf.buf = (char *)fp;
-	pbuf.flags = VF_FILE;
 	VA_START(args, fmt);
-	n = commonprintf(&pbuf, fmt, args);
+	n = Xvfprintf(fp, fmt, args);
 	va_end(args);
 
 	return(n);
 }
 
-VOID fputnl(fp)
-FILE *fp;
+int fputnl(fp)
+XFILE *fp;
 {
-	fputc('\n', fp);
-	fflush(fp);
+	if (Xfputc('\n', fp) == EOF || Xfflush(fp) == EOF) return(-1);
+
+	return(0);
 }
 
 #ifdef	FD
 VOID kanjifputs(s, fp)
 CONST char *s;
-FILE *fp;
+XFILE *fp;
 {
-	fprintf2(fp, "%k", s);
+	Xfprintf(fp, "%k", s);
 }
 #endif	/* FD */
