@@ -13,21 +13,21 @@
 #include <sys/stropts.h>
 #endif
 
-#define	TTY_GROUP	"tty"
+#define	TTY_GROUP		"tty"
 #ifndef	_PATH_PTY
-#define	_PATH_PTY	"/dev/pty"
+#define	_PATH_PTY		"/dev/pty"
 #endif
 #ifndef	_PATH_DEVPTMX
-#define	_PATH_DEVPTMX	"/dev/ptmx"
+#define	_PATH_DEVPTMX		"/dev/ptmx"
 #endif
 #ifndef	_PATH_DEVPTS
-#define	_PATH_DEVPTS	"/dev/pts"
+#define	_PATH_DEVPTS		"/dev/pts"
 #endif
 #ifndef	O_NOCTTY
-#define	O_NOCTTY	0
+#define	O_NOCTTY		0
 #endif
 #ifndef	EPERM
-#define	EPERM		EACCES
+#define	EPERM			EACCES
 #endif
 
 #ifndef	USEDEVPTMX
@@ -68,10 +68,12 @@ static VOID NEAR Xunlockpt(fd, path)
 int fd;
 CONST char *path;
 {
+#if	defined (USEDEVPTMX) && defined (TIOCSPTLCK)
+	int n;
+#endif
+
 #ifdef	USEDEVPTMX
 # ifdef	TIOCSPTLCK
-	int n;
-
 	n = 0;
 	VOID_C Xioctl(fd, TIOCSPTLCK, &n);
 # else
@@ -91,23 +93,24 @@ CONST char *path;
 char *spath;
 ALLOC_T size;
 {
+#if	!defined (USEDEVPTMX) || !defined (TIOCGPTN)
+	char *cp;
+#endif
+#if	defined (USEDEVPTMX) && defined (TIOCGPTN)
+	int n;
+#endif
+
 #ifdef	USEDEVPTMX
 # ifdef	TIOCGPTN
-	int n;
-
 	if (Xioctl(fd, TIOCGPTN, &n) < 0) return(-1);
-	snprintf2(spath, size, "%s/%d", _PATH_DEVPTS, n);
+	Xsnprintf(spath, size, "%s/%d", _PATH_DEVPTS, n);
 # else
-	char *cp;
-
 	if (!(cp = ptsname(fd))) return(-1);
-	snprintf2(spath, size, "%s", cp);
+	Xsnprintf(spath, size, "%s", cp);
 # endif
 #else	/* !USEDEVPTMX */
-	char *cp;
-
-	snprintf2(spath, size, "%s", path);
-	if ((cp = strrchr(spath, '/'))) *(++cp) = 't';
+	Xsnprintf(spath, size, "%s", path);
+	if ((cp = Xstrrchr(spath, '/'))) *(++cp) = 't';
 #endif	/* !USEDEVPTMX */
 
 	return(0);
@@ -122,7 +125,7 @@ ALLOC_T size;
 	int master, slave;
 
 #ifdef	USEDEVPTMX
-	snprintf2(path, sizeof(path), "%s", _PATH_DEVPTMX);
+	Xsnprintf(path, sizeof(path), "%s", _PATH_DEVPTMX);
 	if ((master = Xopen(path, O_RDWR, 0, XF_IGNOREERR)) < 0) return(-1);
 
 	Xgrantpt(master, path);
@@ -136,7 +139,7 @@ ALLOC_T size;
 	CONST char *cp1, *cp2;
 	int n;
 
-	n = snprintf2(path, sizeof(path), "%sXX", _PATH_PTY);
+	n = Xsnprintf(path, sizeof(path), "%sXX", _PATH_PTY);
 	n -= 2;
 	master = slave = -1;
 	for (cp1 = pty_char1; *cp1; cp1++) {
@@ -184,15 +187,15 @@ CONST char *path, *tty, *ws;
 
 	VOID_C Xsetsid();
 
-	Xclose(STDIN_FILENO, pathstdin);
-	Xclose(STDOUT_FILENO, pathstdout);
-	Xclose(STDERR_FILENO, pathstderr);
+	VOID_C Xclose(STDIN_FILENO, pathstdin);
+	VOID_C Xclose(STDOUT_FILENO, pathstdout);
+	VOID_C Xclose(STDERR_FILENO, pathstderr);
 	if ((fd = Xopen(path, O_RDWR, 0, XF_IGNOREERR)) < 0) return(-1);
 
 #ifdef	I_PUSH
 	if (Xioctl(fd, I_PUSH, "ptem") < 0
 	|| Xioctl(fd, I_PUSH, "ldterm") < 0) {
-		Xclose(fd, path);
+		VOID_C Xclose(fd, path);
 		return(-1);
 	}
 # if	defined (SOLARIS) || defined (NEWS_OS6)
@@ -201,7 +204,7 @@ CONST char *path, *tty, *ws;
 #endif	/* I_PUSH */
 #ifdef	TIOCSCTTY
 	if (Xioctl(fd, TIOCSCTTY, NULL) < 0) {
-		Xclose(fd, path);
+		VOID_C Xclose(fd, path);
 		return(-1);
 	}
 #endif
@@ -231,12 +234,12 @@ CONST char *tty, *ws;
 		pid = (p_id_t)-1;
 	}
 	else if ((pid = Xfork()) < (p_id_t)0) term_safeclose(*fdp, pathpty);
-	else if (pid) VOID_C Xread(fds[0], &uc, sizeof(uc), -1, NULL);
+	else if (pid) VOID_C Xread(fds[0], (char *)&uc, sizeof(uc), -1, NULL);
 	else {
 		term_safeclose(*fdp, pathpty);
 		n = Xlogin_tty(path, tty, ws);
 		uc = '\n';
-		VOID_C Xwrite(fds[1], &uc, sizeof(uc), -1, NULL);
+		VOID_C Xwrite(fds[1], (char *)&uc, sizeof(uc), -1, NULL);
 		if (n < 0) _exit(1);
 	}
 
@@ -255,7 +258,7 @@ int argc;
 char *CONST argv[], *envp[];
 {
 	char *tty, *ws, *prog, *path, *args[3], buf[MAXLINEBUF + 1];
-	ALLOC_T ptr;
+	ALLOC_T ptr, len;
 	p_id_t pid;
 	time_t last;
 	u_char uc;
@@ -270,7 +273,7 @@ char *CONST argv[], *envp[];
 	pwd_envp = envp;
 	auth_passwd = "testpass";
 
-	if ((prog = strrchr(path, '/'))) prog++;
+	if ((prog = Xstrrchr(path, '/'))) prog++;
 	else prog = path;
 
 	args[0] = prog;
@@ -280,8 +283,8 @@ char *CONST argv[], *envp[];
 	term_getterm(&tty, &ws);
 	sig_blockchild();
 	pid = Xforkpty(&fd, tty, ws);
-	if (tty) free(tty);
-	if (ws) free(ws);
+	if (tty) Xfree(tty);
+	if (ws) Xfree(ws);
 	if (pid > (p_id_t)0) wait_push(pid);
 	sig_unblockchild();
 
@@ -300,7 +303,7 @@ char *CONST argv[], *envp[];
 	for (;;) {
 		ptr = (ALLOC_T)0;
 		for (;;) {
-			n = Xread(fd, &uc, sizeof(uc), 0, NULL);
+			n = Xread(fd, (char *)&uc, sizeof(uc), 0, NULL);
 			if (n <= 0 || uc == '\r' || uc == '\n') break;
 			buf[ptr] = uc;
 			if (ptr < strsize(buf)) ptr++;
@@ -341,11 +344,17 @@ char *CONST argv[], *envp[];
 			continue;
 
 		uc = '\r';
-		n = Xwrite(fd,
-			(u_char *)auth_passwd, strlen(auth_passwd), 0, prog);
-		if (n < 0) break;
-		n = Xwrite(fd, (u_char *)&uc, sizeof(uc), 0, prog);
-		if (n < 0) break;
+		len = strlen(auth_passwd);
+		n = Xwrite(fd, auth_passwd, len, 0, prog);
+		if (n < (int)len) {
+			n = -1;
+			break;
+		}
+		n = Xwrite(fd, (char *)&uc, sizeof(uc), 0, prog);
+		if (n < (int)sizeof(uc)) {
+			n = -1;
+			break;
+		}
 
 		fprintf(stdout, "pty input: \"%s\"\n", auth_passwd);
 		if (Xusleep((u_long)1000000 / 2) < 0) break;
