@@ -9,14 +9,13 @@
 #include <pwd.h>
 #include <grp.h>
 #include <netdb.h>
-#include <sys/param.h>
 
-#define	PWD_BUFSIZ	127
-#define	PWD_ALL		"ALL"
-#define	PWD_ALLLEN	strsize(PWD_ALL)
+#define	PWD_BUFSIZ		127
+#define	PWD_ALL			"ALL"
+#define	PWD_ALLLEN		strsize(PWD_ALL)
 
 #ifndef	MAXHOSTNAMELEN
-#define	MAXHOSTNAMELEN	256
+#define	MAXHOSTNAMELEN		256
 #endif
 
 static struct NEAR passwd *Xgetpwnam __P_((CONST char *));
@@ -93,12 +92,12 @@ struct passwd *pwd;
 }
 
 char *pwd_gethome(uid)
-uid_t uid;
+u_id_t uid;
 {
 	struct passwd *pwd;
 
 	errno = 0;
-	if (!(pwd = getpwuid(uid))) {
+	if (!(pwd = getpwuid((uid_t)uid))) {
 		ERRORx(("%d: No such user ID", uid));
 		return(NULL);
 	}
@@ -136,9 +135,9 @@ struct passwd *pwd;
 		next = cp;
 		while (*(cp = next)) {
 			for (len = (ALLOC_T)0; cp[len]; len++)
-				if (isspace2(cp[len])) break;
+				if (Xisspace(cp[len])) break;
 			next = &(cp[len]);
-			while (isspace2(*next)) next++;
+			while (Xisspace(*next)) next++;
 			cp[len] = '\0';
 
 			if (len == PWD_ALLLEN && !strncmp(cp, PWD_ALL, len))
@@ -175,14 +174,14 @@ struct passwd *pwd;
 	int flags;
 
 	if (mhprofile && *mhprofile) {
-		snprintf2(path, sizeof(path),
+		Xsnprintf(path, sizeof(path),
 			"%s/%s", pwd -> pw_dir, mhprofile);
 		flags = (XF_IGNOREERR | XF_INHEAD | XF_ENDOFHEAD
 			| XF_NOCOMMENT | XF_FORUSER);
 		if (conf_load(path, flags) < 0) return(-1);
 	}
 	if (mhpopdrc && *mhpopdrc) {
-		snprintf2(path, sizeof(path),
+		Xsnprintf(path, sizeof(path),
 			"%s/%s", pwd -> pw_dir, mhpopdrc);
 		flags = (XF_INHEAD | XF_FORUSER);
 		if (conf_load(path, flags) < 0) return(-1);
@@ -210,10 +209,10 @@ CONST char *path;
 	if (!(cp = Xfgets(fp, &len, XF_TRUNC)) || !len) {
 		if (!Xferror(fp)) ERRORx(("%s: Empty password file", path));
 		Xfree(cp);
-		Xfclose(fp);
+		VOID_C Xfclose(fp);
 		return(NULL);
 	}
-	Xfclose(fp);
+	VOID_C Xfclose(fp);
 
 	n = passwd_decode(buf, sizeof(buf), cp);
 	Xfree(cp);
@@ -243,8 +242,8 @@ CONST char *s;
 	else if (mypasswd && *mypasswd) cp = Xstrdup(mypasswd);
 	else if (passwdfile && *passwdfile) {
 		if (*passwdfile == '/')
-			snprintf2(path, sizeof(path), "%s", passwdfile);
-		else snprintf2(path, sizeof(path),
+			Xsnprintf(path, sizeof(path), "%s", passwdfile);
+		else Xsnprintf(path, sizeof(path),
 			"%s/%s", pwd -> pw_dir, passwdfile);
 		cp = pwd_decode(path);
 	}
