@@ -5,7 +5,6 @@
  */
 
 #include "mhpopd.h"
-#include <signal.h>
 
 #ifdef	USERESOURCEH
 #include <sys/time.h>
@@ -22,17 +21,17 @@ typedef struct _sigtype_t {
 	u_char flags;
 	u_char tmpflags;
 } sigtype_t;
-#define	SIG_ACTION	00007
-#define	SIG_IGNORE	00001
-#define	SIG_TRAP	00002
-#define	SIG_TERM	00003
-#define	SIG_FAULT	00004
-#define	SIG_TYPE	00070
-#define	SIG_HUP		00010
-#define	SIG_INT		00020
-#define	SIG_CHLD	00030
-#define	SIG_CAUGHT	00001
-#define	SIG_HANDLED	00002
+#define	SIG_ACTION		00007
+#define	SIG_IGNORE		00001
+#define	SIG_TRAP		00002
+#define	SIG_TERM		00003
+#define	SIG_FAULT		00004
+#define	SIG_TYPE		00070
+#define	SIG_HUP			00010
+#define	SIG_INT			00020
+#define	SIG_CHLD		00030
+#define	SIG_CAUGHT		00001
+#define	SIG_HANDLED		00002
 
 static char **sig_rmvlist = NULL;
 
@@ -94,7 +93,7 @@ static sigtype_t sig_list[] = {
 	{SIGCHLD, trap_chld, SIG_TRAP | SIG_CHLD, 0},
 #endif
 };
-#define	SIGLISTSIZ	arraysize(sig_list)
+#define	SIGLISTSIZ		arraysize(sig_list)
 
 
 static sigcst_t NEAR Xsignal(sig, func)
@@ -337,6 +336,9 @@ VOID sig_unlink(VOID_A)
 int sig_check(lvl)
 int lvl;
 {
+#ifdef	USERESOURCEH
+	struct rlimit lim;
+#endif
 	static int sig_status = 1;
 	sigmask_t mask, omask;
 	int i, ret, hup, chld, term, fault, duperrno;
@@ -367,13 +369,17 @@ int lvl;
 		switch (sig_list[i].flags & SIG_TYPE) {
 			case SIG_HUP:
 				if (!ischild) hup = i;
-				else sig_list[hup].tmpflags |= SIG_HANDLED;
+				else {
+					sig_list[i].tmpflags |= SIG_HANDLED;
+					wait_killall(sig_list[i].sig);
+					term = i;
+				}
 				break;
 			case SIG_INT:
 				sig_list[i].tmpflags |= SIG_HANDLED;
 				term = i;
 				if (ischild || !interactive) break;
-				fprintf(stderr, "^C\n");
+				Xfprintf(Xstderr, "^C\n");
 				break;
 			case SIG_CHLD:
 				chld = i;
@@ -403,9 +409,8 @@ int lvl;
 	}
 
 	if (fault >= 0) {
+		printf_urgent++;
 #ifdef	USERESOURCEH
-		struct rlimit lim;
-
 		if (getrlimit(RLIMIT_CORE, &lim) >= 0) {
 			lim.rlim_cur = COREDUMPSIZE;
 			setrlimit(RLIMIT_CORE, &lim);
@@ -416,6 +421,7 @@ int lvl;
 		sig_unlink();
 		ERROR0(("Killed by signal (%d)", fault));
 		log_end();
+		printf_urgent--;
 		abort();
 		log_init();
 		term = fault;
