@@ -23,7 +23,7 @@ typedef struct _field_t {
 	CONST char *alter;
 	fieldfunc_t func;
 } field_t;
-#define	DEFFLD(i,a,f)			{i, strsize(i), a, f}
+#define	DEFFLD(i,a,f)		{i, strsize(i), a, f}
 
 CONST char smtp_xorigstr[] = "X-Orig-";
 char *smtp_domain = NULL;
@@ -57,7 +57,7 @@ static CONST field_t fieldlist[] = {
 	DEFFLD("Delivered-To", NULL, NULL),
 	DEFFLD("Message-Id", NULL, NULL),
 };
-#define	FIELDLISTSIZ	arraysize(fieldlist)
+#define	FIELDLISTSIZ		arraysize(fieldlist)
 
 
 static char *NEAR smtp_parseerror(fp, code, mes, s)
@@ -101,8 +101,8 @@ XFILE *fp;
 			return(smtp_parseerror(fp, 553, "Unbalanced ')'", s));
 		if (--paren) continue;
 
-		while (bol > s && isspace2(*(bol - 1))) bol--;
-		while (++cp < eol) if (!isspace2(*cp)) break;
+		while (bol > s && Xisspace(*(bol - 1))) bol--;
+		while (++cp < eol) if (!Xisspace(*cp)) break;
 		memmove(bol, cp, eol - cp + 1);
 		eol -= cp - bol;
 		cp = bol - 1;
@@ -123,8 +123,8 @@ XFILE *fp;
 	if (!s) return(NULL);
 	if (!*s) return(smtp_parseerror(fp, 550, "<> User unknown", s));
 
-	bol = strchr(s, '<');
-	eol = strrchr(s, '>');
+	bol = Xstrchr(s, '<');
+	eol = Xstrrchr(s, '>');
 	if (!bol) {
 		if (!eol) return(s);
 		return(smtp_parseerror(fp, 553, "Unbalanced '>'", s));
@@ -167,8 +167,8 @@ XFILE *fp;
 	if (!cp || cp == nullline) return(cp);
 
 	len = strlen(cp);
-	while (len && isspace2(cp[len - 1])) len--;
-	for (ptr = (ALLOC_T)0; ptr < len; ptr++) if (!isspace2(cp[ptr])) break;
+	while (len && Xisspace(cp[len - 1])) len--;
+	for (ptr = (ALLOC_T)0; ptr < len; ptr++) if (!Xisspace(cp[ptr])) break;
 	if (ptr) memmove(cp, &(cp[ptr]), len -= ptr);
 	cp[len] = '\0';
 
@@ -220,7 +220,7 @@ ALLOC_T *lenp, len;
 	next = *lenp;
 	n = 0;
 	for (ptr = len + 1; ptr < *lenp; ptr = next) {
-		while (ptr < *lenp && isspace2(buf[ptr])) ptr++;
+		while (ptr < *lenp && Xisspace(buf[ptr])) ptr++;
 
 		paren = 0;
 		for (next = ptr; next < *lenp; next++) {
@@ -236,7 +236,7 @@ ALLOC_T *lenp, len;
 			if (!(smtp_forward[i])) i = -1;
 			Xfree(cp);
 		}
-		while (next < *lenp) if (!isspace2(buf[++next])) break;
+		while (next < *lenp) if (!Xisspace(buf[++next])) break;
 
 		if (i >= 0) {
 			Xfree(smtp_forward[i]);
@@ -251,9 +251,9 @@ ALLOC_T *lenp, len;
 			next = ptr;
 		}
 		else {
-			while (ptr && isspace2(buf[ptr - 1])) ptr--;
+			while (ptr && Xisspace(buf[ptr - 1])) ptr--;
 			if (ptr && buf[ptr - 1] == ',') ptr--;
-			while (next && isspace2(buf[next - 1])) next--;
+			while (next && Xisspace(buf[next - 1])) next--;
 			memmove(&(buf[ptr]), &(buf[next]), *lenp - next + 1);
 			*lenp -= next - ptr;
 			next = ptr;
@@ -303,9 +303,9 @@ XFILE *fp;
 
 	if (!smtp_reverse || !*smtp_reverse || (smtp_flags & SMTP_HASFROM))
 		return(0);
-	n = snprintf2(buf, sizeof(buf), "%s: %s\n", SMTP_FROM, smtp_reverse);
+	n = Xsnprintf(buf, sizeof(buf), "%s: %s\n", SMTP_FROM, smtp_reverse);
 
-	return(Xfwrite((u_char *)buf, n, fp));
+	return((Xfwrite(buf, n, fp) < n) ? -1 : 0);
 }
 
 static int NEAR smtp_addbcc(fp)
@@ -316,11 +316,11 @@ XFILE *fp;
 
 	if (list_count(smtp_forward) <= 0) return(0);
 
-	n = snprintf2(buf, sizeof(buf), "%s: ", SMTP_BCC);
+	n = Xsnprintf(buf, sizeof(buf), "%s: ", SMTP_BCC);
 	for (i = 0; smtp_forward[i]; i++) {
-		n += snprintf2(&(buf[n]), (int)sizeof(buf) - n,
+		n += Xsnprintf(&(buf[n]), (int)sizeof(buf) - n,
 			"%s\n", smtp_forward[i]);
-		if (Xfwrite((u_char *)buf, n, fp) < 0) return(-1);
+		if (Xfwrite(buf, n, fp) < n) return(-1);
 		n = 0;
 		buf[n++] = '\t';
 	}
@@ -335,10 +335,10 @@ XFILE *fp;
 	int n, len;
 
 	cp = conf_getversion(&len);
-	n = snprintf2(buf, sizeof(buf),
+	n = Xsnprintf(buf, sizeof(buf),
 		"%s: %s (Ver. %-.*s)\n", SMTP_FORWARDER, myname, len, cp);
 
-	return(Xfwrite((u_char *)buf, n, fp));
+	return((Xfwrite(buf, n, fp) < n) ? -1 : 0);
 }
 
 static int NEAR smtp_closehead(fp)
@@ -348,7 +348,7 @@ XFILE *fp;
 	|| smtp_addforwarder(fp) < 0)
 		return(-1);
 
-	return(Xfputc('\n', fp));
+	return((Xfputc('\n', fp) == EOF) ? -1 : 0);
 }
 
 int smtp_spool(fpin)
@@ -381,14 +381,14 @@ XFILE *fpin;
 		else if (flags & XF_INHEAD)
 			n = smtp_getfield(&buf, &len, flags);
 
-		if (!n) n = Xfwrite((u_char *)buf, len, fpout);
+		if (!n) n = (Xfwrite(buf, len, fpout) < (int)len) ? -1 : 0;
 		Xfree(buf);
 		if (n < 0) break;
 	}
 
 	if (n >= 0 && (flags & XF_INHEAD)) n = smtp_closehead(fpout);
-	if (n >= 0) n = Xfflush(fpout);
-	Xfclose(fpout);
+	if (n >= 0) n = (Xfflush(fpout) == EOF) ? -1 : 0;
+	VOID_C Xfclose(fpout);
 	if (n < 0) return(-1);
 
 	return(mh_send(file));
