@@ -64,7 +64,7 @@ static CONST smtpcmd_t smtpcmdlist[] = {
 	DEFCMD("HELP", smtp_help, SMTP_EXTRA | SMTP_NOAUTH | SMTP_NOHELP),
 	DEFCMD("*", smtp_noauth, SMTP_NOAUTH | SMTP_NOHELP),
 };
-#define	SMTPCMDLISTSIZ	arraysize(smtpcmdlist)
+#define	SMTPCMDLISTSIZ		arraysize(smtpcmdlist)
 
 
 static int NEAR smtp_helo(argv, fp)
@@ -89,7 +89,9 @@ static int NEAR smtp_ehlo(argv, fp)
 char *CONST *argv;
 XFILE *fp;
 {
-	int i, n;
+	CONST char *cp;
+	char buf[SMTP_MAXBUF];
+	int i, n, count;
 
 	if (smtp_domain) {
 		ERROR0(("Duplcate EHLO"));
@@ -97,21 +99,26 @@ XFILE *fp;
 	}
 	if (!(argv[0])) return(smtp_send(fp, 501, "No domain specified"));
 	if (!(smtp_domain = Xstrdup(argv[0]))) return(smtp_senderror(fp));
-	for (i = n = 0; i < SMTPCMDLISTSIZ; i++)
-		if (smtpcmdlist[i].flags & SMTP_EXTRA) n++;
-	if (n) smtp_flags |= SMTP_CONTINUED;
+	for (i = count = 0; i < SMTPCMDLISTSIZ; i++)
+		if (smtpcmdlist[i].flags & SMTP_EXTRA) count++;
+	if (count) smtp_flags |= SMTP_CONTINUED;
 	if (smtp_send(fp, 250, "%s Hello %s", mydomain, argv[0]) < 0)
 		return(-1);
 	for (i = 0; i < SMTPCMDLISTSIZ; i++) {
 		if (!(smtpcmdlist[i].flags & SMTP_EXTRA)) continue;
-		if (!(--n)) smtp_flags &= ~SMTP_CONTINUED;
+		cp = smtpcmdlist[i].ident;
 		if (smtpcmdlist[i].flags & SMTP_AUTHEHLO) {
-			if (auth_ehlo(smtpcmdlist[i].ident, fp) < 0)
+			n = Xsnprintf(buf, sizeof(buf), "%s ", cp);
+			if (auth_genlist(&(buf[n]), sizeof(buf) - n) < 0)
 				return(-1);
-			continue;
+			if (!buf[n]) continue;
+			smtp_flags |= SMTP_CONTINUED;
+			if (smtp_send(fp, 250, buf) < 0) return(-1);
+			buf[smtpcmdlist[i].len] = '=';
+			cp = buf;
 		}
-		if (smtp_send(fp, 250, "%s", smtpcmdlist[i].ident) < 0)
-			return(-1);
+		if (!(--count)) smtp_flags &= ~SMTP_CONTINUED;
+		if (smtp_send(fp, 250, "%s", cp) < 0) return(-1);
 	}
 
 	smtp_status = SMTP_STAT_HELO;
@@ -339,14 +346,23 @@ XFILE *fpin, *fpout;
 {
 	ALLOC_T len, size;
 	char *buf, **argv;
-	int i, n;
+	int i, n, thru;
 
 	if (smtp_status == SMTP_STAT_DATA) {
+		thru = -1;
+		if (fpin -> fd == fpout -> fd && sock_issocket(fpin -> fd)) {
+			VOID_C Xfflush(fpout);
+			thru = sock_changeopt(fpin -> fd, SCK_THROUGHPUT);
+		}
 		n = smtp_spool(fpin);
 		Xfree(smtp_reverse);
 		smtp_reverse = NULL;
 		list_free(smtp_forward);
 		smtp_forward = NULL;
+		if (thru >= 0) {
+			VOID_C Xfflush(fpout);
+			VOID_C sock_changeopt(fpin -> fd, SCK_LOWDELAY);
+		}
 		smtp_status = SMTP_STAT_AUTH;
 
 		if (n < 0) return(smtp_senderror(fpout));
@@ -365,7 +381,7 @@ XFILE *fpin, *fpout;
 	}
 
 	for (len = (ALLOC_T)0; len < size; len++)
-		if (isblank2(buf[len])) break;
+		if (Xisblank(buf[len])) break;
 	for (i = 0; i < SMTPCMDLISTSIZ; i++) {
 		if (len != smtpcmdlist[i].len) continue;
 		if (!Xstrncasecmp(buf, smtpcmdlist[i].ident, len)) break;
