@@ -5,7 +5,6 @@
  */
 
 #include "mhpopd.h"
-#include "printf.h"
 #include "smtp.h"
 
 
@@ -27,12 +26,12 @@ va_dcl
 
 	VA_START(args, fmt);
 	c = (smtp_flags & SMTP_CONTINUED) ? '-' : ' ';
-	n = snprintf2(buf, sizeof(buf), "%<03d%c", code, c);
-	n += vsnprintf2(&(buf[n]), sizeof(buf) - n, fmt, args);
-	n += snprintf2(&(buf[n]), sizeof(buf) - n, "\r\n");
+	n = Xsnprintf(buf, sizeof(buf), "%<03d%c", code, c);
+	n += Xvsnprintf(&(buf[n]), (int)sizeof(buf) - n, fmt, args);
+	n += Xsnprintf(&(buf[n]), (int)sizeof(buf) - n, "\n");
 	va_end(args);
 
-	return(Xfwrite((u_char *)buf, n, fp));
+	return((Xfwrite(buf, n, fp) < n) ? -1 : 0);
 }
 
 int smtp_senderror(fp)
