@@ -5,9 +5,15 @@
  */
 
 #include "mhpopd.h"
+#include "fileio.h"
 #include "kctype.h"
-#include <sys/socket.h>
+
+#ifdef	USEINSYSTMH
+#include <netinet/in_systm.h>
+#endif
+
 #include <netinet/in.h>
+#include <netinet/ip.h>
 #include <arpa/inet.h>
 
 static int NEAR Xsocket __P_((int, int, int));
@@ -83,6 +89,67 @@ int s, level, optname, val;
 	return(-1);
 }
 
+int sock_changeopt(s, opt)
+int s, opt;
+{
+#if	defined (IPPROTO_IP) && defined (IP_TOS)
+	int tos;
+#endif
+	int n;
+
+	n = 0;
+#if	defined (IPPROTO_IP) && defined (IP_TOS)
+	switch (opt & SCK_TOSTYPE) {
+# ifdef	IPTOS_LOWDELAY
+		case SCK_LOWDELAY:
+			tos = IPTOS_LOWDELAY;
+			break;
+# endif
+# ifdef	IPTOS_THROUGHPUT
+		case SCK_THROUGHPUT:
+			tos = IPTOS_THROUGHPUT;
+			break;
+# endif
+# ifdef	IPTOS_RELIABILITY
+		case SCK_RELIABILITY:
+			tos = IPTOS_RELIABILITY;
+			break;
+# endif
+# ifdef	IPTOS_MINCOST
+		case SCK_MINCOST:
+			tos = IPTOS_MINCOST;
+			break;
+# endif
+		case SCK_NORMAL:
+			tos = 0;
+			break;
+		default:
+			tos = -1;
+			break;
+	}
+	if (tos >= 0) {
+		if (Xsetsockopt(s, IPPROTO_IP, IP_TOS, tos) < 0) n = -1;
+	}
+#endif	/* IPPROTO_IP && IP_TOS */
+#ifdef	SOL_SOCKET
+# ifdef	SO_KEEPALIVE
+	if (opt & SCK_KEEPALIVE) {
+		if (Xsetsockopt(s, SOL_SOCKET, SO_KEEPALIVE, 1) < 0) n = -1;
+	}
+# endif
+	if (opt & SCK_REUSEADDR) {
+# ifdef	SO_REUSEADDR
+		if (Xsetsockopt(s, SOL_SOCKET, SO_REUSEADDR, 1) < 0) n = -1;
+# endif
+# ifdef	SO_REUSEPORT
+		if (Xsetsockopt(s, SOL_SOCKET, SO_REUSEPORT, 1) < 0) n = -1;
+# endif
+	}
+#endif	/* SOL_SOCKET */
+
+	return(n);
+}
+
 static int NEAR Xbind(s, addr, len)
 int s;
 struct sockaddr *addr;
@@ -165,7 +232,7 @@ int port;
 	struct sockaddr_in sin;
 	sock_len_t len;
 	p_id_t pid;
-	int s, fd;
+	int n, s, fd;
 
 	memset((char *)&sin, 0, sizeof(sin));
 	sin.sin_family = AF_INET;
@@ -174,26 +241,11 @@ int port;
 
 	if ((s = Xsocket(AF_INET, SOCK_STREAM, 0)) < 0) return(-1);
 
-#ifdef	SO_REUSEADDR
-	if (Xsetsockopt(s, SOL_SOCKET, SO_REUSEADDR, 1) < 0) {
-		Xclose(s, pathsocket);
-		return(-1);
-	}
-#endif
-#ifdef	SO_REUSEPORT
-	if (Xsetsockopt(s, SOL_SOCKET, SO_REUSEPORT, 1) < 0) {
-		Xclose(s, pathsocket);
-		return(-1);
-	}
-#endif
-
-	if (Xbind(s, (struct sockaddr *)&sin, sizeof(sin)) < 0) {
-		Xclose(s, pathsocket);
-		return(-1);
-	}
-
-	if (Xlisten(s, MAXBACKLOG) < 0) {
-		Xclose(s, pathsocket);
+	n = sock_changeopt(s, SCK_LOWDELAY | SCK_KEEPALIVE | SCK_REUSEADDR);
+	if (n >= 0) n = Xbind(s, (struct sockaddr *)&sin, sizeof(sin));
+	if (n >= 0) n = Xlisten(s, MAXBACKLOG);
+	if (n < 0) {
+		VOID_C Xclose(s, pathsocket);
 		return(-1);
 	}
 
@@ -202,7 +254,7 @@ int port;
 		if ((fd = accept(s, (struct sockaddr *)&sin, &len)) >= 0) {
 			if (stat_cloexec(fd, pathsocket) < 0) pid = (p_id_t)-1;
 			else if (!(pid = Xfork())) break;
-			Xclose(fd, pathsocket);
+			VOID_C Xclose(fd, pathsocket);
 			if (pid > (p_id_t)0) continue;
 		}
 #ifdef	EAGAIN
@@ -215,7 +267,7 @@ int port;
 		if (errno != EINTR) ERRORx(("Cannot accept socket"));
 		else if (!sig_check(1)) continue;
 
-		Xclose(s, pathsocket);
+		VOID_C Xclose(s, pathsocket);
 		return(-1);
 	}
 
@@ -225,7 +277,7 @@ int port;
 		inet_ntoa(sin.sin_addr), ntohs(sin.sin_port)));
 	sig_child();
 	wait_discard();
-	Xclose(s, pathsocket);
+	VOID_C Xclose(s, pathsocket);
 
 	return(fd);
 }
@@ -238,7 +290,7 @@ ALLOC_T *lenp;
 	ALLOC_T ptr, len;
 
 	if (sig_check(1) < 0) {
-		fp -> flags |= (XF_EOF | XF_ERROR);
+		fp -> status |= (XS_EOF | XS_ERROR);
 		return(NULL);
 	}
 
@@ -253,11 +305,9 @@ ALLOC_T *lenp;
 		Xfree(buf);
 		return(NULL);
 	}
-	if (len && buf[len - 1] == '\r') len--;
-	else DEBUG(1, ("%s: CRLF not exist", buf));
 
 	for (ptr = (ALLOC_T)0; ptr < len; ptr++)
-		if (!isblank2(buf[ptr])) break;
+		if (!Xisblank(buf[ptr])) break;
 	if (ptr > (ALLOC_T)0) memmove(buf, &(buf[ptr]), len -= ptr);
 	buf[len] = '\0';
 	if (lenp) *lenp = len;
