@@ -97,7 +97,7 @@ int stat_cloexec(fd, path)
 int fd;
 CONST char *path;
 {
-	int flags;
+	long flags;
 
 	if ((flags = Xfcntl(fd, F_GETFD, (VOID_P)0, path)) < 0) return(-1);
 	if (Xfcntl(fd, F_SETFD, (VOID_P)(flags | FD_CLOEXEC), path) < 0)
