@@ -12,7 +12,7 @@
 #endif
 
 #ifndef	EPERM
-#define	EPERM		EACCES
+#define	EPERM			EACCES
 #endif
 
 
@@ -73,7 +73,7 @@ int fd, isout, timeout;
 
 int Xread(fd, buf, size, timeout, path)
 int fd;
-u_char *buf;
+char *buf;
 ALLOC_T size;
 int timeout;
 CONST char *path;
@@ -111,28 +111,31 @@ CONST char *path;
 
 int Xwrite(fd, buf, size, timeout, path)
 int fd;
-CONST u_char *buf;
+CONST char *buf;
 ALLOC_T size;
 int timeout;
 CONST char *path;
 {
-	int n, len;
+	int n, len, total;
 
 	if (size <= (ALLOC_T)0) {
 		errno = 0;
 		return(0);
 	}
 
+	total = -1;
 	for (;;) {
 		if ((n = Xselect(fd, 1, timeout)) <= 0) {
-			if (!n && errno == EINTR) return(-1);
+			if (!n && errno == EINTR) return(total);
 			break;
 		}
 
 		if ((len = write(fd, buf, size)) >= 0) {
+			if (total < 0) total = 0;
+			total += len;
 			if (len >= (int)size) {
 				errno = 0;
-				return(0);
+				return(total);
 			}
 			buf += len;
 			size -= len;
@@ -149,7 +152,7 @@ CONST char *path;
 
 	if (path) ERRORx(("%s: Cannot write", path));
 
-	return(-1);
+	return(total);
 }
 
 int Xopen(path, flags, mode, errflags)
@@ -174,7 +177,7 @@ int flags, mode, errflags;
 	return(-1);
 }
 
-VOID Xclose(fd, path)
+int Xclose(fd, path)
 int fd;
 CONST char *path;
 {
@@ -184,7 +187,7 @@ CONST char *path;
 	for (;;) {
 		if (close(fd) >= 0) {
 			errno = duperrno;
-			return;
+			return(0);
 		}
 #ifdef	EAGAIN
 		else if (errno == EAGAIN) continue;
@@ -198,6 +201,8 @@ CONST char *path;
 	if (path) ERRORx(("%s: Cannot close", path));
 
 	errno = duperrno;
+
+	return(-1);
 }
 
 off_t Xlseek(fd, offset, whence, path)
@@ -253,7 +258,9 @@ CONST char *path;
 # ifdef	USEFCNTLOCK
 	struct flock lock;
 	int cmd;
+# endif
 
+# ifdef	USEFCNTLOCK
 	switch (operation & (LOCK_SH | LOCK_EX | LOCK_UN)) {
 		case LOCK_SH:
 			lock.l_type = F_RDLCK;
@@ -267,19 +274,21 @@ CONST char *path;
 	}
 
 	cmd = (operation & LOCK_NB) ? F_SETLK : F_SETLKW;
-	lock.l_start = 0;
+	lock.l_start = lock.l_len = (off_t)0;
 	lock.l_whence = SEEK_SET;
-	lock.l_len = 0;
 
 	if (Xfcntl(fd, cmd, &lock, NULL) >= 0) return(0);
 # else	/* !USEFCNTLOCK */
 #  ifdef	USELOCKF
 	switch (operation & (LOCK_SH | LOCK_EX | LOCK_UN)) {
-		case LOCK_UN:
-			operation = F_ULOCK;
+		case LOCK_SH:
+			operation = F_TEST;
+			break;
+		case LOCK_EX:
+			operation = (operation & LOCK_NB) ? F_TLOCK : F_LOCK;
 			break;
 		default:
-			operation = (operation & LOCK_NB) ? F_TLOCK : F_LOCK;
+			operation = F_ULOCK;
 			break;
 	}
 #  endif	/* USELOCKF */
@@ -379,6 +388,23 @@ CONST char *path;
 	return(-1);
 }
 
+int Xmkdir(path, mode)
+CONST char *path;
+int mode;
+{
+	for (;;) {
+		if (mkdir(path, mode) >= 0 || errno == EEXIST) {
+			errno = 0;
+			return(0);
+		}
+		else if (errno != EINTR || sig_check(0) < 0) break;
+	}
+
+	ERRORx(("%s: Cannot make directory", path));
+
+	return(-1);
+}
+
 int Xrename(old, new)
 CONST char *old, *new;
 {
