@@ -73,7 +73,8 @@ static int NEAR term_noctl __P_((int));
 
 
 int Xioctl(fd, request, argp)
-int fd, request;
+int fd;
+ioctlreq_t request;
 VOID_P argp;
 {
 	for (;;) {
@@ -209,7 +210,7 @@ CONST char *path;
 	if (fd < 0) return;
 	duperrno = errno;
 	if (fd != STDIN_FILENO && fd != STDOUT_FILENO && fd != STDERR_FILENO)
-		Xclose(fd, path);
+		VOID_C Xclose(fd, path);
 	errno = duperrno;
 }
 
@@ -252,22 +253,22 @@ char **ttyp, **wsp;
 #ifdef	USESGTTY
 		size += sizeof(int) + sizeof(struct tchars);
 #endif
-		if (!(tty = (char *)malloc(size))) break;
+		if (!(tty = Xmalloc(size))) break;
 
 		size = (ALLOC_T)0;
 		if (tioctl(fd, REQGETP, (termioctl_t *)&(tty[size])) < 0) {
-			free(tty);
+			Xfree(tty);
 			break;
 		}
 #ifdef	USESGTTY
 		size += sizeof(termioctl_t);
 		if (Xioctl(fd, TIOCLGET, (int *)&(tty[size])) < 0) {
-			free(tty);
+			Xfree(tty);
 			break;
 		}
 		size += sizeof(int);
 		if (Xioctl(fd, TIOCGETC, (struct tchars *)&(tty[size])) < 0) {
-			free(tty);
+			Xfree(tty);
 			break;
 		}
 #endif	/* USESGTTY */
@@ -277,10 +278,10 @@ char **ttyp, **wsp;
 	if (wsp) do {
 		*wsp = NULL;
 #ifndef	NOTERMWSIZE
-		if (!(ws = (char *)malloc(sizeof(termwsize_t)))) break;
+		if (!(ws = Xmalloc(sizeof(termwsize_t)))) break;
 
 		if (Xioctl(fd, REQGETWS, (termwsize_t *)ws) < 0) {
-			free(ws);
+			Xfree(ws);
 			break;
 		}
 		*wsp = ws;
