@@ -4,19 +4,15 @@
  *	type definitions
  */
 
-#include <sys/types.h>
+#include "depend.h"
+#include "typesize.h"
+#include "stream.h"
 
 #ifdef	NOUID_T
 typedef u_short			uid_t;
 typedef u_short			gid_t;
 #endif
 
-#ifdef	USEPID_T
-typedef pid_t			p_id_t;
-#else
-typedef long			p_id_t;
-#endif
-
 #ifdef	SIGARGINT
 typedef int			sigarg_t;
 #else
@@ -57,31 +53,6 @@ typedef int			wait_pid_t;
 typedef int			sock_len_t;
 #endif
 
-#ifndef	XF_BUFSIZ
-#define	XF_BUFSIZ		((ALLOC_T)BUFSIZ)
-#endif
-typedef struct _XFILE {
-	int fd;
-	int timeout;
-	u_char buf[XF_BUFSIZ];
-	off_t inptr;
-	off_t outptr;
-	off_t inmax;
-	CONST char *debugmes;
-	int flags;
-	char path[1];
-} XFILE;
-#define	XF_DEBUGLVL		000017
-#define	XF_EOF			000020
-#define	XF_ERROR		000040
-#define	XF_LOCKED		000100
-#define	XF_NOCLOSE		000200
-#define	XF_CONNECTED		000400
-#define	XF_READ			001000
-#define	XF_WRITTEN		002000
-#define	XF_RDONLY		004000
-#define	XF_WRONLY		010000
-
 /* Flags for functions */
 #define	XF_IGNOREERR		000001			/* Xfopen() */
 #define	XF_IGNORENOENT		000002			/* Xfopen() */
